% Auto-generated chapter 76 for bukhari
% Hadiths in this chapter: 93

\hadithdefcmd{bukhari}{5678}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا أَبُو أَحْمَدَ الزُّبَيْرِيُّ، حَدَّثَنَا عُمَرُ بْنُ سَعِيدِ بْنِ أَبِي حُسَيْنٍ، قَالَ حَدَّثَنِي عَطَاءُ بْنُ أَبِي رَبَاحٍ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَا أَنْزَلَ اللَّهُ دَاءً إِلاَّ أَنْزَلَ لَهُ شِفَاءً ‏"‏‏.‏\hadithno{5678}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "There is no disease that Allah has created, except that He also has created its treatment}}
\hadithdefcmd{bukhari}{5679}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا بِشْرُ بْنُ الْمُفَضَّلِ، عَنْ خَالِدِ بْنِ ذَكْوَانَ، عَنْ رُبَيِّعَ بِنْتِ مُعَوِّذٍ ابْنِ عَفْرَاءَ، قَالَتْ كُنَّا نَغْزُو مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم نَسْقِي الْقَوْمَ، وَنَخْدُمُهُمْ، وَنَرُدُّ الْقَتْلَى وَالْجَرْحَى إِلَى الْمَدِينَةِ‏.‏\hadithno{5679}\hadithtrans{Narrated Rubai bint Mu`adh bin Afra:We used to go for Military expeditions along with Allah's Messenger (ﷺ) and provide the people with water, serve them and bring the dead and the wounded back to Medina}}
\hadithdefcmd{bukhari}{5680}{حَدَّثَنِي الْحُسَيْنُ، حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا مَرْوَانُ بْنُ شُجَاعٍ، حَدَّثَنَا سَالِمٌ الأَفْطَسُ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ ‏ "‏ الشِّفَاءُ فِي ثَلاَثَةٍ شَرْبَةِ عَسَلٍ، وَشَرْطَةِ مِحْجَمٍ، وَكَيَّةِ نَارٍ، وَأَنْهَى أُمَّتِي عَنِ الْكَىِّ ‏"‏‏.‏ رَفَعَ الْحَدِيثَ وَرَوَاهُ الْقُمِّيُّ عَنْ لَيْثٍ عَنْ مُجَاهِدٍ عَنِ ابْنِ عَبَّاسٍ عَنِ النَّبِيِّ صلى الله عليه وسلم فِي الْعَسَلِ وَالْحَجْمِ‏.‏\hadithno{5680}\hadithtrans{Narrated Ibn `Abbas:(The Prophet (ﷺ) said), "Healing is in three things: A gulp of honey, cupping, and branding with fire (cauterizing)." But I forbid my followers to use (cauterization) branding with fire}}
\hadithdefcmd{bukhari}{5681}{حَدَّثَنِي مُحَمَّدُ بْنُ عَبْدِ الرَّحِيمِ، أَخْبَرَنَا سُرَيْجُ بْنُ يُونُسَ أَبُو الْحَارِثِ، حَدَّثَنَا مَرْوَانُ بْنُ شُجَاعٍ، عَنْ سَالِمٍ الأَفْطَسِ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ الشِّفَاءُ فِي ثَلاَثَةٍ شَرْطَةِ مِحْجَمٍ، أَوْ شَرْبَةِ عَسَلٍ، أَوْ كَيَّةٍ بِنَارٍ، وَأَنْهَى أُمَّتِي عَنِ الْكَىِّ ‏"‏‏.‏\hadithno{5681}\hadithtrans{Narrated Ibn `Abbas:The Prophet (ﷺ) said, "Healing is in three things: cupping, a gulp of honey or cauterization, (branding with fire) but I forbid my followers to use cauterization (branding with fire)}}
\hadithdefcmd{bukhari}{5682}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا أَبُو أُسَامَةَ، قَالَ أَخْبَرَنِي هِشَامٌ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ كَانَ النَّبِيُّ صلى الله عليه وسلم يُعْجِبُهُ الْحَلْوَاءُ وَالْعَسَلُ‏.‏\hadithno{5682}\hadithtrans{Narrated `Aisha:The Prophet (ﷺ) used to like sweet edible things and honey}}
\hadithdefcmd{bukhari}{5683}{حَدَّثَنَا أَبُو نُعَيْمٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ الْغَسِيلِ، عَنْ عَاصِمِ بْنِ عُمَرَ بْنِ قَتَادَةَ، قَالَ سَمِعْتُ جَابِرَ بْنَ عَبْدِ اللَّهِ ـ رضى الله عنهما ـ قَالَ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِنْ كَانَ فِي شَىْءٍ مِنْ أَدْوِيَتِكُمْ ـ أَوْ يَكُونُ فِي شَىْءٍ مِنْ أَدْوِيَتِكُمْ ـ خَيْرٌ فَفِي شَرْطَةِ مِحْجَمٍ، أَوْ شَرْبَةِ عَسَلٍ، أَوْ لَذْعَةٍ بِنَارٍ تُوَافِقُ الدَّاءَ، وَمَا أُحِبُّ أَنْ أَكْتَوِيَ ‏"‏‏.‏\hadithno{5683}\hadithtrans{Narrated Jabir bin `Abdullah:I heard the Prophet (ﷺ) saying, "If there is any healing in your medicines, then it is in cupping, a gulp of honey or branding with fire (cauterization) that suits the ailment, but I don't like to be (cauterized) branded with fire}}
\hadithdefcmd{bukhari}{5684}{حَدَّثَنَا عَيَّاشُ بْنُ الْوَلِيدِ، حَدَّثَنَا عَبْدُ الأَعْلَى، حَدَّثَنَا سَعِيدٌ، عَنْ قَتَادَةَ، عَنْ أَبِي الْمُتَوَكِّلِ، عَنْ أَبِي سَعِيدٍ، أَنَّ رَجُلاً، أَتَى النَّبِيَّ صلى الله عليه وسلم فَقَالَ أَخِي يَشْتَكِي بَطْنَهُ‏.‏ فَقَالَ ‏"‏ اسْقِهِ عَسَلاً ‏"‏‏.‏ ثُمَّ أَتَى الثَّانِيَةَ فَقَالَ ‏"‏ اسْقِهِ عَسَلاً ‏"‏‏.‏ ثُمَّ أَتَاهُ فَقَالَ فَعَلْتُ‏.‏ فَقَالَ ‏"‏ صَدَقَ اللَّهُ، وَكَذَبَ بَطْنُ أَخِيكَ، اسْقِهِ عَسَلاً ‏"‏‏.‏ فَسَقَاهُ فَبَرَأَ‏.‏\hadithno{5684}\hadithtrans{Narrated Abu Sa`id Al-Khudri:A man came to the Prophet (ﷺ) and said, "My brother has some Abdominal trouble." The Prophet (ﷺ) said to him "Let him drink honey." The man came for the second time and the Prophet (ﷺ) said to him, 'Let him drink honey." He came for the third time and the Prophet (ﷺ) said, "Let him drink honey." He returned again and said, "I have done that ' The Prophet (ﷺ) then said, "Allah has said the truth, but your brother's `Abdomen has told a lie. Let him drink honey." So he made him drink honey and he was cured}}
\hadithdefcmd{bukhari}{5685}{حَدَّثَنَا مُسْلِمُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا سَلاَّمُ بْنُ مِسْكِينٍ، حَدَّثَنَا ثَابِتٌ، عَنْ أَنَسٍ، أَنَّ نَاسًا، كَانَ بِهِمْ سَقَمٌ قَالُوا يَا رَسُولَ اللَّهِ آوِنَا وَأَطْعِمْنَا فَلَمَّا صَحُّوا قَالُوا إِنَّ الْمَدِينَةَ وَخِمَةٌ‏.‏ فَأَنْزَلَهُمُ الْحَرَّةَ فِي ذَوْدٍ لَهُ فَقَالَ ‏ "‏ اشْرَبُوا أَلْبَانَهَا ‏"‏‏.‏ فَلَمَّا صَحُّوا قَتَلُوا رَاعِيَ النَّبِيِّ صلى الله عليه وسلم وَاسْتَاقُوا ذَوْدَهُ، فَبَعَثَ فِي آثَارِهِمْ، فَقَطَعَ أَيْدِيَهُمْ وَأَرْجُلَهُمْ، وَسَمَرَ أَعْيُنَهُمْ، فَرَأَيْتُ الرَّجُلَ مِنْهُمْ يَكْدُمُ الأَرْضَ بِلِسَانِهِ حَتَّى يَمُوتَ‏.‏ قَالَ سَلاَّمٌ فَبَلَغَنِي أَنَّ الْحَجَّاجَ قَالَ لأَنَسٍ حَدِّثْنِي بِأَشَدِّ عُقُوبَةٍ عَاقَبَهُ النَّبِيُّ صلى الله عليه وسلم فَحَدَّثَهُ بِهَذَا‏.‏ فَبَلَغَ الْحَسَنَ فَقَالَ وَدِدْتُ أَنَّهُ لَمْ يُحَدِّثْهُ‏ بِهَذَا\hadithno{5685}\hadithtrans{Narrated Anas:Some people were sick and they said, "O Allah's Messenger (ﷺ)! Give us shelter and food. So when they became healthy they said, "The weather of Medina is not suitable for us." So he sent them to Al-Harra with some she-camels of his and said, "Drink of their milk." But when they became healthy, they killed the shepherd of the Prophet (ﷺ) and drove away his camels. The Prophet (ﷺ) sent some people in their pursuit. Then he got their hands and feet cut and their eyes were branded with heated pieces of iron. I saw one of them licking the earth with his tongue till he died}}
\hadithdefcmd{bukhari}{5686}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا هَمَّامٌ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ ـ رضى الله عنه ـ أَنَّ نَاسًا، اجْتَوَوْا فِي الْمَدِينَةِ فَأَمَرَهُمُ النَّبِيُّ صلى الله عليه وسلم أَنْ يَلْحَقُوا بِرَاعِيهِ ـ يَعْنِي الإِبِلَ ـ فَيَشْرَبُوا مِنْ أَلْبَانِهَا وَأَبْوَالِهَا، فَلَحِقُوا بِرَاعِيهِ فَشَرِبُوا مِنْ أَلْبَانِهَا وَأَبْوَالِهَا، حَتَّى صَلَحَتْ أَبْدَانُهُمْ فَقَتَلُوا الرَّاعِيَ وَسَاقُوا الإِبِلَ، فَبَلَغَ النَّبِيَّ صلى الله عليه وسلم فَبَعَثَ فِي طَلَبِهِمْ، فَجِيءَ بِهِمْ فَقَطَعَ أَيْدِيَهُمْ وَأَرْجُلَهُمْ، وَسَمَرَ أَعْيُنَهُمْ‏.‏ قَالَ قَتَادَةُ فَحَدَّثَنِي مُحَمَّدُ بْنُ سِيرِينَ أَنَّ ذَلِكَ كَانَ قَبْلَ أَنْ تَنْزِلَ الْحُدُودُ‏.‏\hadithno{5686}\hadithtrans{Narrated Anas:The climate of Medina did not suit some people, so the Prophet (ﷺ) ordered them to follow his shepherd, i.e. his camels, and drink their milk and urine (as a medicine). So they followed the shepherd that is the camels and drank their milk and urine till their bodies became healthy. Then they killed the shepherd and drove away the camels. When the news reached the Prophet (ﷺ) he sent some people in their pursuit. When they were brought, he cut their hands and feet and their eyes were branded with heated pieces of iron}}
\hadithdefcmd{bukhari}{5687}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عُبَيْدُ اللَّهِ، حَدَّثَنَا إِسْرَائِيلُ، عَنْ مَنْصُورٍ، عَنْ خَالِدِ بْنِ سَعْدٍ، قَالَ خَرَجْنَا وَمَعَنَا غَالِبُ بْنُ أَبْجَرَ فَمَرِضَ فِي الطَّرِيقِ، فَقَدِمْنَا الْمَدِينَةَ وَهْوَ مَرِيضٌ، فَعَادَهُ ابْنُ أَبِي عَتِيقٍ فَقَالَ لَنَا عَلَيْكُمْ بِهَذِهِ الْحُبَيْبَةِ السَّوْدَاءِ، فَخُذُوا مِنْهَا خَمْسًا أَوْ سَبْعًا فَاسْحَقُوهَا، ثُمَّ اقْطُرُوهَا فِي أَنْفِهِ بِقَطَرَاتِ زَيْتٍ فِي هَذَا الْجَانِبِ وَفِي هَذَا الْجَانِبِ، فَإِنَّ عَائِشَةَ حَدَّثَتْنِي أَنَّهَا سَمِعَتِ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِنَّ هَذِهِ الْحَبَّةَ السَّوْدَاءَ شِفَاءٌ مِنْ كُلِّ دَاءٍ إِلاَّ مِنَ السَّامِ ‏"‏‏.‏ قُلْتُ وَمَا السَّامُ قَالَ الْمَوْتُ‏.‏\hadithno{5687}\hadithtrans{Narrated Khalid bin Sa`d:We went out and Ghalib bin Abjar was accompanying us. He fell ill on the way and when we arrived at Medina he was still sick. Ibn Abi 'Atiq came to visit him and said to us, "Treat him with black cumin. Take five or seven seeds and crush them (mix the powder with oil) and drop the resulting mixture into both nostrils, for `Aisha has narrated to me that she heard the Prophet (ﷺ) saying, 'This black cumin is healing for all diseases except As-Sam.' Aisha said, 'What is As-Sam?' He said, 'Death}}
\hadithdefcmd{bukhari}{5688}{حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، حَدَّثَنَا اللَّيْثُ، عَنْ عُقَيْلٍ، عَنِ ابْنِ شِهَابٍ، قَالَ أَخْبَرَنِي أَبُو سَلَمَةَ، وَسَعِيدُ بْنُ الْمُسَيَّبِ، أَنَّ أَبَا هُرَيْرَةَ، أَخْبَرَهُمَا أَنَّهُ، سَمِعَ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ فِي الْحَبَّةِ السَّوْدَاءِ شِفَاءٌ مِنْ كُلِّ دَاءٍ إِلاَّ السَّامَ ‏"‏‏.‏ قَالَ ابْنُ شِهَابٍ وَالسَّامُ الْمَوْتُ، وَالْحَبَّةُ السَّوْدَاءُ الشُّونِيزُ‏.‏\hadithno{5688}\hadithtrans{Narrated Abu Huraira:I heard Allah's Messenger (ﷺ) saying, "There is healing in black cumin for all diseases except death}}
\hadithdefcmd{bukhari}{5689}{حَدَّثَنَا حِبَّانُ بْنُ مُوسَى، أَخْبَرَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا يُونُسُ بْنُ يَزِيدَ، عَنْ عُقَيْلٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ أَنَّهَا كَانَتْ تَأْمُرُ بِالتَّلْبِينِ لِلْمَرِيضِ وَلِلْمَحْزُونِ عَلَى الْهَالِكِ، وَكَانَتْ تَقُولُ إِنِّي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِنَّ التَّلْبِينَةَ تُجِمُّ فُؤَادَ الْمَرِيضِ، وَتَذْهَبُ بِبَعْضِ الْحُزْنِ ‏"‏‏.‏\hadithno{5689}\hadithtrans{Narrated 'Urwa:Aisha used to recommend at-Talbina for the sick and for such a person as grieved over a dead person. She used to say, "I heard Allah's Messenger (ﷺ) saying, 'at-Talbina gives rest to the heart of the patient and makes it active and relieves some of his sorrow and grief}}
\hadithdefcmd{bukhari}{5690}{حَدَّثَنَا فَرْوَةُ بْنُ أَبِي الْمَغْرَاءِ، حَدَّثَنَا عَلِيُّ بْنُ مُسْهِرٍ، عَنْ هِشَامٍ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، أَنَّهَا كَانَتْ تَأْمُرُ بِالتَّلْبِينَةِ وَتَقُولُ هُوَ الْبَغِيضُ النَّافِعُ‏.‏\hadithno{5690}\hadithtrans{Narrated Hisham's father:`Aisha used to recommend at-Talbina and used to say, "It is disliked (by the patient) although it is beneficial}}
\hadithdefcmd{bukhari}{5691}{حَدَّثَنَا مُعَلَّى بْنُ أَسَدٍ، حَدَّثَنَا وُهَيْبٌ، عَنِ ابْنِ طَاوُسٍ، عَنْ أَبِيهِ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ عَنِ النَّبِيِّ صلى الله عليه وسلم احْتَجَمَ وَأَعْطَى الْحَجَّامَ أَجْرَهُ وَاسْتَعَطَ‏.‏\hadithno{5691}\hadithtrans{Narrated Ibn `Abbas:The Prophet (ﷺ) was cupped and he paid the wages to the one who had cupped him and then took Su'ut (Medicine sniffed by nose)}}
\hadithdefcmd{bukhari}{5693}{حَدَّثَنَا صَدَقَةُ بْنُ الْفَضْلِ، أَخْبَرَنَا ابْنُ عُيَيْنَةَ، قَالَ سَمِعْتُ الزُّهْرِيَّ، عَنْ عُبَيْدِ اللَّهِ، عَنْ أُمِّ قَيْسٍ بِنْتِ مِحْصَنٍ، قَالَتْ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏ عَلَيْكُمْ بِهَذَا الْعُودِ الْهِنْدِيِّ، فَإِنَّ فِيهِ سَبْعَةَ أَشْفِيَةٍ‏.‏ يُسْتَعَطُ بِهِ مِنَ الْعُذْرَةِ، وَيُلَدُّ بِهِ مِنْ ذَاتِ الْجَنْبِ ‏"‏‏.‏ وَدَخَلْتُ عَلَى النَّبِيِّ صلى الله عليه وسلم بِابْنٍ لِي لَمْ يَأْكُلِ الطَّعَامَ فَبَالَ عَلَيْهِ، فَدَعَا بِمَاءٍ فَرَشَّ عَلَيْهِ‏.‏\hadithno{5693}\hadithtrans{Narrated Um Qais bint Mihsan:I heard the Prophet (ﷺ) saying, "Treat with the Indian incense, for it has healing for seven diseases; it is to be sniffed by one having throat trouble, and to be put into one side of the mouth of one suffering from pleurisy." Once I went to Allah's Messenger (ﷺ) with a son of mine who would not eat any food, and the boy passed urine on him whereupon he asked for some water and sprinkled it over the place of urine}}
\hadithdefcmd{bukhari}{5694}{حَدَّثَنَا أَبُو مَعْمَرٍ، حَدَّثَنَا عَبْدُ الْوَارِثِ، حَدَّثَنَا أَيُّوبُ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ احْتَجَمَ النَّبِيُّ صلى الله عليه وسلم وَهْوَ صَائِمٌ‏.‏\hadithno{5694}\hadithtrans{Narrated Ibn `Abbas:The Prophet (ﷺ) was cupped while he was fasting}}
\hadithdefcmd{bukhari}{5695}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا سُفْيَانُ، عَنْ عَمْرٍو، عَنْ طَاوُسٍ، وَعَطَاءٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ احْتَجَمَ النَّبِيُّ صلى الله عليه وسلم وَهْوَ مُحْرِمٌ‏.‏\hadithno{5695}\hadithtrans{Narrated Ibn `Abbas:The Prophet (ﷺ) was cupped while he was in a state of Ihram}}
\hadithdefcmd{bukhari}{5696}{حَدَّثَنَا مُحَمَّدُ بْنُ مُقَاتِلٍ، أَخْبَرَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا حُمَيْدٌ الطَّوِيلُ، عَنْ أَنَسٍ ـ رضى الله عنه ـ أَنَّهُ سُئِلَ عَنْ أَجْرِ الْحَجَّامِ، فَقَالَ احْتَجَمَ رَسُولُ اللَّهِ صلى الله عليه وسلم حَجَمَهُ أَبُو طَيْبَةَ، وَأَعْطَاهُ صَاعَيْنِ مِنْ طَعَامٍ، وَكَلَّمَ مَوَالِيَهُ فَخَفَّفُوا عَنْهُ، وَقَالَ ‏"‏ إِنَّ أَمْثَلَ مَا تَدَاوَيْتُمْ بِهِ الْحِجَامَةُ وَالْقُسْطُ الْبَحْرِيُّ ‏"‏‏.‏ وَقَالَ ‏"‏ لاَ تُعَذِّبُوا صِبْيَانَكُمْ بِالْغَمْزِ مِنَ الْعُذْرَةِ، وَعَلَيْكُمْ بِالْقُسْطِ ‏"‏‏.‏\hadithno{5696}\hadithtrans{Narrated Anas:that he was asked about the wages of the one who cups others. He said, 'Allah's Messenger (ﷺ) was cupped by `Abd Taiba, to whom he gave two Sa of food and interceded for him with his masters who consequently reduced what they used to charge him daily. Then the Prophet (ﷺ) said, "The best medicines you may treat yourselves with are cupping and sea incense.' He added, "You should not torture your children by treating tonsillitis by pressing the tonsils or the palate with the finger, but use incense}}
\hadithdefcmd{bukhari}{5697}{حَدَّثَنَا سَعِيدُ بْنُ تَلِيدٍ، قَالَ حَدَّثَنِي ابْنُ وَهْبٍ، قَالَ أَخْبَرَنِي عَمْرٌو، وَغَيْرُهُ، أَنَّ بُكَيْرًا، حَدَّثَهُ أَنَّ عَاصِمَ بْنَ عُمَرَ بْنِ قَتَادَةَ حَدَّثَهُ أَنَّ جَابِرَ بْنَ عَبْدِ اللَّهِ ـ رضى الله عنهما ـ عَادَ الْمُقَنَّعَ ثُمَّ قَالَ لاَ أَبْرَحُ حَتَّى تَحْتَجِمَ فَإِنِّي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِنَّ فِيهِ شِفَاءً ‏"‏‏.‏\hadithno{5697}\hadithtrans{Narrated Jabir bin `Abdullah:that he paid Al-Muqanna a visit during his illness and said, "I will not leave till he gets cupped, for I heard Allah's Messenger (ﷺ) saying, "There is healing in cupping}}
\hadithdefcmd{bukhari}{5699}{حَدَّثَنَا إِسْمَاعِيلُ، قَالَ حَدَّثَنِي سُلَيْمَانُ، عَنْ عَلْقَمَةَ، أَنَّهُ سَمِعَ عَبْدَ الرَّحْمَنِ الأَعْرَجَ، أَنَّهُ سَمِعَ عَبْدَ اللَّهِ ابْنَ بُحَيْنَةَ، يُحَدِّثُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم احْتَجَمَ بِلَحْىِ جَمَلٍ مِنْ طَرِيقِ مَكَّةَ، وَهْوَ مُحْرِمٌ، فِي وَسَطِ رَأْسِهِ‏.‏ وَقَالَ الأَنْصَارِيُّ أَخْبَرَنَا هِشَامُ بْنُ حَسَّانَ، حَدَّثَنَا عِكْرِمَةُ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم احْتَجَمَ فِي رَأْسِهِ‏.‏\hadithno{5699}\hadithtrans{Narrated `Abdullah bin Buhaina:Allah's Messenger (ﷺ) was cupped on the middle of his head at Lahl Jamal on his way to Mecca while he was in a state of Ihram. Narrated Ibn `Abbas: Allah's Messenger (ﷺ) was cupped on his head}}
\hadithdefcmd{bukhari}{5701}{حَدَّثَنِي مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، عَنْ هِشَامٍ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، احْتَجَمَ النَّبِيُّ صلى الله عليه وسلم فِي رَأْسِهِ وَهْوَ مُحْرِمٌ مِنْ وَجَعٍ كَانَ بِهِ بِمَاءٍ يُقَالُ لَهُ لَحْىُ جَمَلٍ‏.‏ وَقَالَ مُحَمَّدُ بْنُ سَوَاءٍ أَخْبَرَنَا هِشَامٌ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم احْتَجَمَ وَهْوَ مُحْرِمٌ فِي رَأْسِهِ مِنْ شَقِيقَةٍ كَانَتْ بِهِ‏.‏\hadithno{5701}\hadithtrans{Narrated Ibn `Abbas:The Prophet (ﷺ) was cupped on his head for an ailment he was suffering from while he was in a state of Ihram. at a water place called Lahl Jamal. Ibn `Abbas further said: Allah's Apostle was cupped on his head for unilateral headache while he was in a state of Ihram}}
\hadithdefcmd{bukhari}{5702}{حَدَّثَنَا إِسْمَاعِيلُ بْنُ أَبَانَ، حَدَّثَنَا ابْنُ الْغَسِيلِ، قَالَ حَدَّثَنِي عَاصِمُ بْنُ عُمَرَ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِنْ كَانَ فِي شَىْءٍ مِنْ أَدْوِيَتِكُمْ خَيْرٌ فَفِي شَرْبَةِ عَسَلٍ أَوْ شَرْطَةِ مِحْجَمٍ أَوْ لَذْعَةٍ مِنْ نَارٍ، وَمَا أُحِبُّ أَنْ أَكْتَوِيَ ‏"‏‏.‏\hadithno{5702}\hadithtrans{Narrated Jabir bin `Abdullah:I heard the Prophet (ﷺ) saying, "If there is any good in your medicines, then it is in a gulp of honey, a cupping operation, or branding (cauterization), but I do not like to be (cauterized) branded}}
\hadithdefcmd{bukhari}{5703}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا حَمَّادٌ، عَنْ أَيُّوبَ، قَالَ سَمِعْتُ مُجَاهِدًا، عَنِ ابْنِ أَبِي لَيْلَى، عَنْ كَعْبٍ، هُوَ ابْنُ عُجْرَةَ قَالَ أَتَى عَلَىَّ النَّبِيُّ صلى الله عليه وسلم زَمَنَ الْحُدَيْبِيَةِ، وَأَنَا أُوقِدُ تَحْتَ بُرْمَةٍ، وَالْقَمْلُ يَتَنَاثَرُ عَنْ رَأْسِي فَقَالَ ‏"‏ أَيُؤْذِيكَ هَوَامُّكَ ‏"‏‏.‏ قُلْتُ نَعَمْ‏.‏ قَالَ ‏"‏ فَاحْلِقْ وَصُمْ ثَلاَثَةَ أَيَّامٍ، أَوْ أَطْعِمْ سِتَّةً، أَوِ انْسُكْ نَسِيكَةً ‏"‏‏.‏ قَالَ أَيُّوبُ لاَ أَدْرِي بِأَيَّتِهِنَّ بَدَأَ‏.‏\hadithno{5703}\hadithtrans{Narrated Ka`b bin Ujrah:The Prophet (ﷺ) came to me during the period of Al-Hudaibiya, while I was lighting fire underneath a cooking pot and lice were falling down my head. He said, "Do your lice hurt your?" I said, "Yes." He said, "Shave your head and fast for three days or feed six poor persons or slaughter a sheep as a sacrifice:}}
\hadithdefcmd{bukhari}{5704}{حَدَّثَنَا أَبُو الْوَلِيدِ، هِشَامُ بْنُ عَبْدِ الْمَلِكِ حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ سُلَيْمَانَ بْنِ الْغَسِيلِ، حَدَّثَنَا عَاصِمُ بْنُ عُمَرَ بْنِ قَتَادَةَ، قَالَ سَمِعْتُ جَابِرًا، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِنْ كَانَ فِي شَىْءٍ مِنْ أَدْوِيَتِكُمْ شِفَاءٌ فَفِي شَرْطَةِ مِحْجَمٍ أَوْ لَذْعَةٍ بِنَارٍ، وَمَا أُحِبُّ أَنْ أَكْتَوِيَ ‏"‏‏.‏\hadithno{5704}\hadithtrans{Narrated Jabir:The Prophet (ﷺ) said, "If there is any healing in your medicines then it is a cupping operation, or branding (cauterization), but I do not like to be (cauterized) branded}}
\hadithdefcmd{bukhari}{5705}{حَدَّثَنَا عِمْرَانُ بْنُ مَيْسَرَةَ، حَدَّثَنَا ابْنُ فُضَيْلٍ، حَدَّثَنَا حُصَيْنٌ، عَنْ عَامِرٍ، عَنْ عِمْرَانَ بْنِ حُصَيْنٍ ـ رضى الله عنهما ـ قَالَ لاَ رُقْيَةَ إِلاَّ مِنْ عَيْنٍ أَوْ حُمَةٍ‏.‏ فَذَكَرْتُهُ لِسَعِيدِ بْنِ جُبَيْرٍ فَقَالَ حَدَّثَنَا ابْنُ عَبَّاسٍ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ عُرِضَتْ عَلَىَّ الأُمَمُ، فَجَعَلَ النَّبِيُّ وَالنَّبِيَّانِ يَمُرُّونَ مَعَهُمُ الرَّهْطُ، وَالنَّبِيُّ لَيْسَ مَعَهُ أَحَدٌ، حَتَّى رُفِعَ لِي سَوَادٌ عَظِيمٌ، قُلْتُ مَا هَذَا أُمَّتِي هَذِهِ قِيلَ هَذَا مُوسَى وَقَوْمُهُ‏.‏ قِيلَ انْظُرْ إِلَى الأُفُقِ‏.‏ فَإِذَا سَوَادٌ يَمْلأُ الأُفُقَ، ثُمَّ قِيلَ لِي انْظُرْ هَا هُنَا وَهَا هُنَا فِي آفَاقِ السَّمَاءِ فَإِذَا سَوَادٌ قَدْ مَلأَ الأُفُقَ قِيلَ هَذِهِ أُمَّتُكَ وَيَدْخُلُ الْجَنَّةَ مِنْ هَؤُلاَءِ سَبْعُونَ أَلْفًا بِغَيْرِ حِسَابٍ، ثُمَّ دَخَلَ وَلَمْ يُبَيِّنْ لَهُمْ فَأَفَاضَ الْقَوْمُ وَقَالُوا نَحْنُ الَّذِينَ آمَنَّا بِاللَّهِ، وَاتَّبَعْنَا رَسُولَهُ، فَنَحْنُ هُمْ أَوْ أَوْلاَدُنَا الَّذِينَ وُلِدُوا فِي الإِسْلاَمِ فَإِنَّا وُلِدْنَا فِي الْجَاهِلِيَّةِ‏.‏ فَبَلَغَ النَّبِيَّ صلى الله عليه وسلم فَخَرَجَ فَقَالَ هُمُ الَّذِينَ لاَ يَسْتَرْقُونَ، وَلاَ يَتَطَيَّرُونَ، وَلاَ يَكْتَوُونَ وَعَلَى رَبِّهِمْ يَتَوَكَّلُونَ ‏"‏‏.‏ فَقَالَ عُكَّاشَةُ بْنُ مِحْصَنٍ أَمِنْهُمْ أَنَا يَا رَسُولَ اللَّهِ قَالَ ‏"‏ نَعَمْ ‏"‏‏.‏ فَقَامَ آخَرُ فَقَالَ أَمِنْهُمْ أَنَا قَالَ ‏"‏ سَبَقَكَ عُكَّاشَةُ ‏"‏‏.‏\hadithno{5705}\hadithtrans{Narrated Ibn `Abbas:Allah's Messenger (ﷺ) said, 'Nations were displayed before me; one or two prophets would pass by along with a few followers. A prophet would pass by accompanied by nobody. Then a big crowd of people passed in front of me and I asked, Who are they Are they my followers?" It was said, 'No. It is Moses and his followers It was said to me, 'Look at the horizon.'' Behold! There was a multitude of people filling the horizon. Then it was said to me, 'Look there and there about the stretching sky! Behold! There was a multitude filling the horizon,' It was said to me, 'This is your nation out of whom seventy thousand shall enter Paradise without reckoning.' "Then the Prophet (ﷺ) entered his house without telling his companions who they (the 70,000) were. So the people started talking about the issue and said, "It is we who have believed in Allah and followed His Apostle; therefore those people are either ourselves or our children who are born m the Islamic era, for we were born in the Pre-Islamic Period of Ignorance.'' When the Prophet (ﷺ) heard of that, he came out and said. "Those people are those who do not treat themselves with Ruqya, nor do they believe in bad or good omen (from birds etc.) nor do they get themselves branded (Cauterized). but they put their trust (only) in their Lord " On that 'Ukasha bin Muhsin said. "Am I one of them, O Allah's Messenger (ﷺ)?' The Prophet (ﷺ) said, "Yes." Then another person got up and said, "Am I one of them?" The Prophet (ﷺ) said, 'Ukasha has anticipated you}}
\hadithdefcmd{bukhari}{5706}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ شُعْبَةَ، قَالَ حَدَّثَنِي حُمَيْدُ بْنُ نَافِعٍ، عَنْ زَيْنَبَ، عَنْ أُمِّ سَلَمَةَ ـ رضى الله عنها ـ أَنَّ امْرَأَةً تُوُفِّيَ زَوْجُهَا فَاشْتَكَتْ عَيْنَهَا، فَذَكَرُوهَا لِلنَّبِيِّ صلى الله عليه وسلم وَذَكَرُوا لَهُ الْكُحْلَ، وَأَنَّهُ يُخَافُ عَلَى عَيْنِهَا، فَقَالَ ‏ "‏ لَقَدْ كَانَتْ إِحْدَاكُنَّ تَمْكُثُ فِي بَيْتِهَا فِي شَرِّ أَحْلاَسِهَا ـ أَوْ فِي أَحْلاَسِهَا فِي شَرِّ بَيْتِهَا ـ فَإِذَا مَرَّ كَلْبٌ رَمَتْ بَعْرَةً، فَلاَ، أَرْبَعَةَ أَشْهُرٍ وَعَشْرًا ‏"‏‏.‏\hadithno{5706}\hadithtrans{Narrated Um Salama:The husband of a lady died and her eyes became sore and the people mentioned her story to the Prophet They asked him whether it was permissible for her to use kohl as her eyes were exposed to danger. He said, "Previously, when one of you was bereaved by a husband she would stay in her dirty clothes in a bad unhealthy house (for one year), and when a dog passed by, she would throw a globe of dung. No, (she should observe the prescribed period Idda) for four months and ten days}}
\hadithdefcmd{bukhari}{5707}{وَقَالَ عَفَّانُ حَدَّثَنَا سَلِيمُ بْنُ حَيَّانَ، حَدَّثَنَا سَعِيدُ بْنُ مِينَاءَ، قَالَ سَمِعْتُ أَبَا هُرَيْرَةَ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ عَدْوَى وَلاَ طِيَرَةَ وَلاَ هَامَةَ وَلاَ صَفَرَ، وَفِرَّ مِنَ الْمَجْذُومِ كَمَا تَفِرُّ مِنَ الأَسَدِ ‏"‏‏.‏\hadithno{5707}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "(There is) no 'Adwa (no contagious disease is conveyed without Allah's permission). nor is there any bad omen (from birds), nor is there any Hamah, nor is there any bad omen in the month of Safar, and one should run away from the leper as one runs away from a lion." Note: The majority of scholars interpret this to mean that these things in and of themselves do not transmit or cause harm through supernatural or hidden means but that Allah is ultimately in control and any fearful superstition around these is false}}
\hadithdefcmd{bukhari}{5708}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا غُنْدَرٌ، حَدَّثَنَا شُعْبَةُ، عَنْ عَبْدِ الْمَلِكِ، سَمِعْتُ عَمْرَو بْنَ حُرَيْثٍ، قَالَ سَمِعْتُ سَعِيدَ بْنَ زَيْدٍ، قَالَ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏ الْكَمْأَةُ مِنَ الْمَنِّ، وَمَاؤُهَا شِفَاءٌ لِلْعَيْنِ ‏"‏‏.‏ قَالَ شُعْبَةُ وَأَخْبَرَنِي الْحَكَمُ بْنُ عُتَيْبَةَ عَنِ الْحَسَنِ الْعُرَنِيِّ عَنْ عَمْرِو بْنِ حُرَيْثٍ عَنْ سَعِيدِ بْنِ زَيْدٍ عَنِ النَّبِيِّ صلى الله عليه وسلم‏.‏ قَالَ شُعْبَةُ لَمَّا حَدَّثَنِي بِهِ الْحَكَمُ لَمْ أُنْكِرْهُ مِنْ حَدِيثِ عَبْدِ الْمَلِكِ‏.‏\hadithno{5708}\hadithtrans{Narrated Sa`id bin Zaid:I heard the Prophet (ﷺ) saying, "Truffles are like Manna (i.e. they grow naturally without man's care) and their water heals eye diseases}}
\hadithdefcmd{bukhari}{5712}{\hadithno{5712}\hadithtrans{}}
\hadithdefcmd{bukhari}{5713}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، أَخْبَرَنِي عُبَيْدُ اللَّهِ، عَنْ أُمِّ قَيْسٍ، قَالَتْ دَخَلْتُ بِابْنٍ لِي عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم وَقَدْ أَعْلَقْتُ عَلَيْهِ مِنَ الْعُذْرَةِ فَقَالَ ‏ "‏ عَلَى مَا تَدْغَرْنَ أَوْلاَدَكُنَّ بِهَذَا الْعِلاَقِ عَلَيْكُنَّ بِهَذَا الْعُودِ الْهِنْدِيِّ، فَإِنَّ فِيهِ سَبْعَةَ أَشْفِيَةٍ، مِنْهَا ذَاتُ الْجَنْبِ يُسْعَطُ مِنَ الْعُذْرَةِ، وَيُلَدُّ مِنْ ذَاتِ الْجَنْبِ ‏"‏‏.‏ فَسَمِعْتُ الزُّهْرِيَّ يَقُولُ بَيَّنَ لَنَا اثْنَيْنِ وَلَمْ يُبَيِّنْ لَنَا خَمْسَةً‏.‏ قُلْتُ لِسُفْيَانَ فَإِنَّ مَعْمَرًا يَقُولُ أَعْلَقْتُ عَلَيْهِ‏.‏ قَالَ لَمْ يَحْفَظْ أَعْلَقْتُ عَنْهُ، حَفِظْتُهُ مِنْ فِي الزُّهْرِيِّ‏.‏ وَوَصَفَ سُفْيَانُ الْغُلاَمَ يُحَنَّكُ بِالإِصْبَعِ وَأَدْخَلَ سُفْيَانُ فِي حَنَكِهِ، إِنَّمَا يَعْنِي رَفْعَ حَنَكِهِ بِإِصْبَعِهِ، وَلَمْ يَقُلْ أَعْلِقُوا عَنْهُ شَيْئًا‏.‏\hadithno{5713}\hadithtrans{Narrated Um Qais:I went to Allah's Messenger (ﷺ) along with a a son of mine whose palate and tonsils I had pressed with my finger as a treatment for a (throat and tonsil) disease. The Prophet (ﷺ) said, "Why do you pain your children by pressing their throats! Use Ud Al-Hindi (certain Indian incense) for it cures seven diseases, one of which is pleurisy. It is used as a snuff for treating throat and tonsil disease and it is inserted into one side of the mouth of one suffering from pleurisy}}
\hadithdefcmd{bukhari}{5714}{حَدَّثَنَا بِشْرُ بْنُ مُحَمَّدٍ، أَخْبَرَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا مَعْمَرٌ، وَيُونُسُ، قَالَ الزُّهْرِيُّ أَخْبَرَنِي عُبَيْدُ اللَّهِ بْنُ عَبْدِ اللَّهِ بْنِ عُتْبَةَ، أَنَّ عَائِشَةَ ـ رضى الله عنها ـ زَوْجَ النَّبِيِّ صلى الله عليه وسلم قَالَتْ لَمَّا ثَقُلَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَاشْتَدَّ وَجَعُهُ، اسْتَأْذَنَ أَزْوَاجَهُ فِي أَنْ يُمَرَّضَ فِي بَيْتِي، فَأَذِنَّ، فَخَرَجَ بَيْنَ رَجُلَيْنِ، تَخُطُّ رِجْلاَهُ فِي الأَرْضِ بَيْنَ عَبَّاسٍ وَآخَرَ‏.‏ فَأَخْبَرْتُ ابْنَ عَبَّاسٍ قَالَ هَلْ تَدْرِي مَنِ الرَّجُلُ الآخَرُ الَّذِي لَمْ تُسَمِّ عَائِشَةُ قُلْتُ لاَ‏.‏ قَالَ هُوَ عَلِيٌّ‏.‏ قَالَتْ عَائِشَةُ فَقَالَ النَّبِيُّ صلى الله عليه وسلم بَعْدَ مَا دَخَلَ بَيْتَهَا وَاشْتَدَّ بِهِ وَجَعُهُ ‏ "‏ هَرِيقُوا عَلَىَّ مِنْ سَبْعِ قِرَبٍ لَمْ تُحْلَلْ أَوْكِيَتُهُنَّ، لَعَلِّي أَعْهَدُ إِلَى النَّاسِ ‏"‏‏.‏ قَالَتْ فَأَجْلَسْنَاهُ فِي مِخْضَبٍ لِحَفْصَةَ زَوْجِ النَّبِيِّ صلى الله عليه وسلم ثُمَّ طَفِقْنَا نَصُبُّ عَلَيْهِ مِنْ تِلْكَ الْقِرَبِ، حَتَّى جَعَلَ يُشِيرُ إِلَيْنَا أَنْ قَدْ فَعَلْتُنَّ‏.‏ قَالَتْ وَخَرَجَ إِلَى النَّاسِ فَصَلَّى لَهُمْ وَخَطَبَهُمْ‏.‏\hadithno{5714}\hadithtrans{Narrated `Aisha:(the wife of the Prophet) When the health of Allah's Messenger (ﷺ) deteriorated and his condition became serious, he asked the permission of all his wives to allow him to be treated In my house, and they allowed him. He came out, supported by two men and his legs were dragging on the ground between `Abbas and another man. (The sub-narrator told Ibn `Abbas who said: Do you know who was the other man whom `Aisha did not mention? The sub-narrator said: No. Ibn `Abbas said: It was `Ali.) `Aisha added: When the Prophet entered my house and his disease became aggravated, he said, "Pour on me seven water skins full of water (the tying ribbons of which had not been untied) so that I may give some advice to the people." So we made him sit in a tub belonging to Hafsa, the wife of the Prophet (ﷺ) and started pouring water on him from those water skins till he waved us to stop. Then he went out to the people and led them in prayer and delivered a speech before them}}
\hadithdefcmd{bukhari}{5715}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي عُبَيْدُ اللَّهِ بْنُ عَبْدِ اللَّهِ، أَنَّ أُمَّ قَيْسٍ بِنْتَ مِحْصَنٍ الأَسَدِيَّةَ ـ أَسَدَ خُزَيْمَةَ، وَكَانَتْ مِنَ الْمُهَاجِرَاتِ الأُوَلِ اللاَّتِي بَايَعْنَ النَّبِيَّ صلى الله عليه وسلم وَهْىَ أُخْتُ عُكَّاشَةَ ـ أَخْبَرَتْهُ أَنَّهَا أَتَتْ رَسُولَ اللَّهِ صلى الله عليه وسلم بِابْنٍ لَهَا، قَدْ أَعْلَقَتْ عَلَيْهِ مِنَ الْعُذْرَةِ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ عَلَى مَا تَدْغَرْنَ أَوْلاَدَكُنَّ بِهَذَا الْعِلاَقِ عَلَيْكُمْ بِهَذَا الْعُودِ الْهِنْدِيِّ، فَإِنَّ فِيهِ سَبْعَةَ أَشْفِيَةٍ مِنْهَا ذَاتُ الْجَنْبِ ‏"‏‏.‏ يُرِيدُ الْكُسْتَ، وَهْوَ الْعُودُ الْهِنْدِيُّ‏.‏ وَقَالَ يُونُسُ وَإِسْحَاقُ بْنُ رَاشِدٍ عَنِ الزُّهْرِيِّ عَلَّقَتْ عَلَيْهِ‏.‏\hadithno{5715}\hadithtrans{Narrated Um Qais:that she took to Allah's Messenger (ﷺ) one of her sons whose palate and tonsils she had pressed because he had throat trouble. The Prophet (ﷺ) said, "Why do you pain your children by getting the palate pressed like that? Use the Ud Al-Hindi (certain Indian incense) for it cures seven diseases one of which is pleurisy}}
\hadithdefcmd{bukhari}{5716}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ قَتَادَةَ، عَنْ أَبِي الْمُتَوَكِّلِ، عَنْ أَبِي سَعِيدٍ، قَالَ جَاءَ رَجُلٌ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ إِنَّ أَخِي اسْتَطْلَقَ بَطْنُهُ‏.‏ فَقَالَ ‏"‏ اسْقِهِ عَسَلاً ‏"‏‏.‏ فَسَقَاهُ‏.‏ فَقَالَ إِنِّي سَقَيْتُهُ فَلَمْ يَزِدْهُ إِلاَّ اسْتِطْلاَقًا‏.‏ فَقَالَ ‏"‏ صَدَقَ اللَّهُ وَكَذَبَ بَطْنُ أَخِيكَ ‏"‏‏.‏ تَابَعَهُ النَّضْرُ عَنْ شُعْبَةَ‏.‏\hadithno{5716}\hadithtrans{Narrated Abu Sa`id:A man came to the prophet and said, 'My brother has got loose motions. The Prophet (ﷺ) said, Let him drink honey." The man again (came) and said, 'I made him drink (honey) but that made him worse.' The Prophet (ﷺ) said, 'Allah has said the Truth, and the `Abdomen of your brother has told a lie." (See Hadith No)}}
\hadithdefcmd{bukhari}{5717}{حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ سَعْدٍ، عَنْ صَالِحٍ، عَنِ ابْنِ شِهَابٍ، قَالَ أَخْبَرَنِي أَبُو سَلَمَةَ بْنُ عَبْدِ الرَّحْمَنِ، وَغَيْرُهُ، أَنَّ أَبَا هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ لاَ عَدْوَى وَلاَ صَفَرَ وَلاَ هَامَةَ ‏"‏‏.‏ فَقَالَ أَعْرَابِيٌّ يَا رَسُولَ اللَّهِ فَمَا بَالُ إِبِلِي تَكُونُ فِي الرَّمْلِ كَأَنَّهَا الظِّبَاءُ فَيَأْتِي الْبَعِيرُ الأَجْرَبُ فَيَدْخُلُ بَيْنَهَا فَيُجْرِبُهَا‏.‏ فَقَالَ ‏"‏ فَمَنْ أَعْدَى الأَوَّلَ ‏"‏‏.‏ رَوَاهُ الزُّهْرِيُّ عَنْ أَبِي سَلَمَةَ وَسِنَانِ بْنِ أَبِي سِنَانٍ‏.‏\hadithno{5717}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, 'There is no 'Adwa (no disease is conveyed from the sick to the healthy without Allah's permission), nor Safar, nor Hama." A bedouin stood up and said, "Then what about my camels? They are like deer on the sand, but when a mangy camel comes and mixes with them, they all get infected with mangy." The Prophet (ﷺ) said, "Then who conveyed the (mange) disease to the first one?}}
\hadithdefcmd{bukhari}{5718}{حَدَّثَنِي مُحَمَّدٌ، أَخْبَرَنَا عَتَّابُ بْنُ بَشِيرٍ، عَنْ إِسْحَاقَ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي عُبَيْدُ اللَّهِ بْنُ عَبْدِ اللَّهِ، أَنَّ أُمَّ قَيْسٍ بِنْتَ مِحْصَنٍ،، وَكَانَتْ، مِنَ الْمُهَاجِرَاتِ الأُوَلِ اللاَّتِي بَايَعْنَ رَسُولَ اللَّهِ صلى الله عليه وسلم وَهْىَ أُخْتُ عُكَّاشَةَ بْنِ مِحْصَنٍ أَخْبَرَتْهُ أَنَّهَا أَتَتْ رَسُولَ اللَّهِ صلى الله عليه وسلم بِابْنٍ لَهَا قَدْ عَلَّقَتْ عَلَيْهِ مِنَ الْعُذْرَةِ فَقَالَ ‏ "‏ اتَّقُوا اللَّهَ، عَلَى مَا تَدْغَرُونَ أَوْلاَدَكُمْ بِهَذِهِ الأَعْلاَقِ عَلَيْكُمْ بِهَذَا الْعُودِ الْهِنْدِيِّ، فَإِنَّ فِيهِ سَبْعَةَ أَشْفِيَةٍ، مِنْهَا ذَاتُ الْجَنْبِ ‏"‏‏.‏ يُرِيدُ الْكُسْتَ يَعْنِي الْقُسْطَ، قَالَ وَهْىَ لُغَةٌ‏.‏\hadithno{5718}\hadithtrans{Narrated Um Oais:that she took to Allah's Messenger (ﷺ) one of her sons whose palate and tonsils she had pressed to treat a throat trouble. The Prophet (ﷺ) said, "Be afraid of Allah! Why do you pain your children by having their tonsils pressed like that? Use the Ud Al-Hindi (a certain Indian incense) for it cures seven diseases, one of which is pleurisy}}
\hadithdefcmd{bukhari}{5721}{حَدَّثَنَا عَارِمٌ، حَدَّثَنَا حَمَّادٌ، قَالَ قُرِئَ عَلَى أَيُّوبَ مِنْ كُتُبِ أَبِي قِلاَبَةَ، مِنْهُ مَا حَدَّثَ بِهِ وَمِنْهُ مَا قُرِئَ عَلَيْهِ، وَكَانَ هَذَا فِي الْكِتَابِ عَنْ أَنَسٍ أَنَّ أَبَا طَلْحَةَ وَأَنَسَ بْنَ النَّضْرِ كَوَيَاهُ، وَكَوَاهُ أَبُو طَلْحَةَ بِيَدِهِ‏.‏ وَقَالَ عَبَّادُ بْنُ مَنْصُورٍ عَنْ أَيُّوبَ، عَنْ أَبِي قِلاَبَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ أَذِنَ رَسُولُ اللَّهِ صلى الله عليه وسلم لأَهْلِ بَيْتٍ مِنَ الأَنْصَارِ أَنْ يَرْقُوا مِنَ الْحُمَةِ وَالأُذُنِ‏.‏ قَالَ أَنَسٌ كُوِيتُ مِنْ ذَاتِ الْجَنْبِ وَرَسُولُ اللَّهِ صلى الله عليه وسلم حَىٌّ، وَشَهِدَنِي أَبُو طَلْحَةَ وَأَنَسُ بْنُ النَّضْرِ وَزَيْدُ بْنُ ثَابِتٍ، وَأَبُو طَلْحَةَ كَوَانِي‏.‏\hadithno{5721}\hadithtrans{Narrated Anas bin Malik:Allah's Messenger (ﷺ) allowed one of the Ansar families to treat persons who have taken poison and also who are suffering from ear ailment with Ruqya. Anas added: I got myself branded cauterized) for pleurisy, when Allah's Messenger (ﷺ) was still alive. Abu Talha, Anas bin An-Nadr and Zaid bin Thabit witnessed that, and it was Abu Talha who branded (cauterized) me}}
\hadithdefcmd{bukhari}{5722}{حَدَّثَنِي سَعِيدُ بْنُ عُفَيْرٍ، حَدَّثَنَا يَعْقُوبُ بْنُ عَبْدِ الرَّحْمَنِ الْقَارِيُّ، عَنْ أَبِي حَازِمٍ، عَنْ سَهْلِ بْنِ سَعْدٍ السَّاعِدِيِّ، قَالَ لَمَّا كُسِرَتْ عَلَى رَأْسِ رَسُولِ اللَّهِ صلى الله عليه وسلم الْبَيْضَةُ، وَأُدْمِيَ وَجْهُهُ، وَكُسِرَتْ رَبَاعِيَتُهُ، وَكَانَ عَلِيٌّ يَخْتَلِفُ بِالْمَاءِ فِي الْمِجَنِّ، وَجَاءَتْ فَاطِمَةُ تَغْسِلُ عَنْ وَجْهِهِ الدَّمَ، فَلَمَّا رَأَتْ فَاطِمَةُ ـ عَلَيْهَا السَّلاَمُ ـ الدَّمَ يَزِيدُ عَلَى الْمَاءِ كَثْرَةً عَمَدَتْ إِلَى حَصِيرٍ فَأَحْرَقَتْهَا وَأَلْصَقَتْهَا عَلَى جُرْحِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَرَقَأَ الدَّمُ‏.‏\hadithno{5722}\hadithtrans{Narrated Sahl bin Sa`d As-Sa`idi:When the helmet broke on the head of the Prophet (ﷺ) and his face became covered with blood and his incisor tooth broke (i.e. during the battle of Uhud), `Ali used to bring water in his shield while Fatima was washing the blood off his face. When Fatima saw that the bleeding increased because of the water, she took a mat (of palm leaves), burnt it, and stuck it (the burnt ashes) on the wound of Allah's Apostle, whereupon the bleeding stopped}}
\hadithdefcmd{bukhari}{5723}{حَدَّثَنِي يَحْيَى بْنُ سُلَيْمَانَ، حَدَّثَنِي ابْنُ وَهْبٍ، قَالَ حَدَّثَنِي مَالِكٌ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ الْحُمَّى مِنْ فَيْحِ جَهَنَّمَ فَأَطْفِئُوهَا بِالْمَاءِ ‏"‏‏.‏ قَالَ نَافِعٌ وَكَانَ عَبْدُ اللَّهِ يَقُولُ اكْشِفْ عَنَّا الرِّجْزَ‏.‏\hadithno{5723}\hadithtrans{Narrated Nazi':`Abdullah bin `Umar said, "The Prophet (ﷺ) said, 'Fever is from the heat of Hell, so put it out (cool it) with water.' " Nafi` added: `Abdullah used to say, "O Allah! Relieve us from the punishment," (when he suffered from fever)}}
\hadithdefcmd{bukhari}{5724}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، عَنْ مَالِكٍ، عَنْ هِشَامٍ، عَنْ فَاطِمَةَ بِنْتِ الْمُنْذِرِ، أَنَّ أَسْمَاءَ بِنْتَ أَبِي بَكْرٍ ـ رضى الله عنهما ـ كَانَتْ إِذَا أُتِيَتْ بِالْمَرْأَةِ قَدْ حُمَّتْ تَدْعُو لَهَا، أَخَذَتِ الْمَاءَ فَصَبَّتْهُ بَيْنَهَا وَبَيْنَ جَيْبِهَا قَالَتْ وَكَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَأْمُرُنَا أَنْ نَبْرُدَهَا بِالْمَاءِ‏.‏\hadithno{5724}\hadithtrans{Narrated Fatima bint Al-Mundhir:Whenever a lady suffering from fever was brought to Asma' bint Abu Bakr, she used to invoke Allah for her and then sprinkle some water on her body, at the chest and say, "Allah's Messenger (ﷺ) used to order us to abate fever with water}}
\hadithdefcmd{bukhari}{5725}{حَدَّثَنِي مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا يَحْيَى، حَدَّثَنَا هِشَامٌ، أَخْبَرَنِي أَبِي، عَنْ عَائِشَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ الْحُمَّى مِنْ فَيْحِ جَهَنَّمَ فَابْرُدُوهَا بِالْمَاءِ ‏"‏‏.‏\hadithno{5725}\hadithtrans{Narrated `Aisha:The Prophet (ﷺ) said, "Fever is from the heat of Hell, so abate fever with water}}
\hadithdefcmd{bukhari}{5726}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا أَبُو الأَحْوَصِ، حَدَّثَنَا سَعِيدُ بْنُ مَسْرُوقٍ، عَنْ عَبَايَةَ بْنِ رِفَاعَةَ، عَنْ جَدِّهِ، رَافِعِ بْنِ خَدِيجٍ قَالَ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏ الْحُمَّى مِنْ فَوْحِ جَهَنَّمَ، فَابْرُدُوهَا بِالْمَاءِ ‏"‏‏.‏\hadithno{5726}\hadithtrans{Narrated Rafi` bin Khadij:I heard Allah's Messenger (ﷺ) saying, "Fever is from the heat of Hell, so abate fever with water}}
\hadithdefcmd{bukhari}{5727}{حَدَّثَنَا عَبْدُ الأَعْلَى بْنُ حَمَّادٍ، حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، حَدَّثَنَا سَعِيدٌ، حَدَّثَنَا قَتَادَةُ، أَنَّ أَنَسَ بْنَ مَالِكٍ، حَدَّثَهُمْ أَنَّ نَاسًا أَوْ رِجَالاً مِنْ عُكْلٍ وَعُرَيْنَةَ قَدِمُوا عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم وَتَكَلَّمُوا بِالإِسْلاَمِ وَقَالُوا يَا نَبِيَّ اللَّهِ إِنَّا كُنَّا أَهْلَ ضَرْعٍ، وَلَمْ نَكُنْ أَهْلَ رِيفٍ، وَاسْتَوْخَمُوا الْمَدِينَةَ فَأَمَرَ لَهُمْ رَسُولُ اللَّهِ صلى الله عليه وسلم بِذَوْدٍ وَبِرَاعٍ وَأَمَرَهُمْ، أَنْ يَخْرُجُوا فِيهِ فَيَشْرَبُوا مِنْ أَلْبَانِهَا وَأَبْوَالِهَا، فَانْطَلَقُوا حَتَّى كَانُوا نَاحِيَةَ الْحَرَّةِ، كَفَرُوا بَعْدَ إِسْلاَمِهِمْ، وَقَتَلُوا رَاعِيَ رَسُولِ اللَّهِ صلى الله عليه وسلم وَاسْتَاقُوا الذَّوْدَ فَبَلَغَ النَّبِيَّ صلى الله عليه وسلم فَبَعَثَ الطَّلَبَ فِي آثَارِهِمْ، وَأَمَرَ بِهِمْ فَسَمَرُوا أَعْيُنَهُمْ وَقَطَعُوا أَيْدِيَهُمْ وَتُرِكُوا فِي نَاحِيَةِ الْحَرَّةِ حَتَّى مَاتُوا عَلَى حَالِهِمْ‏.‏\hadithno{5727}\hadithtrans{Narrated Anas bin Malik:Some people from the tribes of `Ukl and `Uraina came to Allah's Messenger (ﷺ) and embraced Islam and said, "O Allah's Messenger (ﷺ)! We are owners of livestock and have never been farmers," and they found the climate of Medina unsuitable for them. So Allah's Messenger (ﷺ) ordered that they be given some camels and a shepherd, and ordered them to go out with those camels and drink their milk and urine. So they set out, but when they reached a place called Al-Harra, they reverted to disbelief after their conversion to Islam, killed the shepherd and drove away the camels. When this news reached the Prophet (ﷺ) he sent in their pursuit (and they were caught and brought). The Prophet (ﷺ) ordered that their eyes be branded with heated iron bars and their hands be cut off, and they were left at Al-Harra till they died in that state}}
\hadithdefcmd{bukhari}{5728}{حَدَّثَنَا حَفْصُ بْنُ عُمَرَ، حَدَّثَنَا شُعْبَةُ، قَالَ أَخْبَرَنِي حَبِيبُ بْنُ أَبِي ثَابِتٍ، قَالَ سَمِعْتُ إِبْرَاهِيمَ بْنَ سَعْدٍ، قَالَ سَمِعْتُ أُسَامَةَ بْنَ زَيْدٍ، يُحَدِّثُ سَعْدًا عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا سَمِعْتُمْ بِالطَّاعُونِ بِأَرْضٍ فَلاَ تَدْخُلُوهَا، وَإِذَا وَقَعَ بِأَرْضٍ وَأَنْتُمْ بِهَا فَلاَ تَخْرُجُوا مِنْهَا ‏"‏‏.‏ فَقُلْتُ أَنْتَ سَمِعْتَهُ يُحَدِّثُ سَعْدًا وَلاَ يُنْكِرُهُ قَالَ نَعَمْ‏.‏\hadithno{5728}\hadithtrans{Narrated Saud:The Prophet (ﷺ) said, "If you hear of an outbreak of plague in a land, do not enter it; but if the plague breaks out in a place while you are in it, do not leave that place}}
\hadithdefcmd{bukhari}{5729}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنِ ابْنِ شِهَابٍ، عَنْ عَبْدِ الْحَمِيدِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ زَيْدِ بْنِ الْخَطَّابِ، عَنْ عَبْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ الْحَارِثِ بْنِ نَوْفَلٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَبَّاسٍ، أَنَّ عُمَرَ بْنَ الْخَطَّابِ ـ رضى الله عنه ـ خَرَجَ إِلَى الشَّأْمِ حَتَّى إِذَا كَانَ بِسَرْغَ لَقِيَهُ أُمَرَاءُ الأَجْنَادِ أَبُو عُبَيْدَةَ بْنُ الْجَرَّاحِ وَأَصْحَابُهُ، فَأَخْبَرُوهُ أَنَّ الْوَبَاءَ قَدْ وَقَعَ بِأَرْضِ الشَّأْمِ‏.‏ قَالَ ابْنُ عَبَّاسٍ فَقَالَ عُمَرُ ادْعُ لِي الْمُهَاجِرِينَ الأَوَّلِينَ‏.‏ فَدَعَاهُمْ فَاسْتَشَارَهُمْ وَأَخْبَرَهُمْ أَنَّ الْوَبَاءَ قَدْ وَقَعَ بِالشَّأْمِ فَاخْتَلَفُوا‏.‏ فَقَالَ بَعْضُهُمْ قَدْ خَرَجْتَ لأَمْرٍ، وَلاَ نَرَى أَنْ تَرْجِعَ عَنْهُ‏.‏ وَقَالَ بَعْضُهُمْ مَعَكَ بَقِيَّةُ النَّاسِ وَأَصْحَابُ رَسُولِ اللَّهِ صلى الله عليه وسلم وَلاَ نَرَى أَنْ تُقْدِمَهُمْ عَلَى هَذَا الْوَبَاءِ‏.‏ فَقَالَ ارْتَفِعُوا عَنِّي‏.‏ ثُمَّ قَالَ ادْعُوا لِي الأَنْصَارَ‏.‏ فَدَعَوْتُهُمْ فَاسْتَشَارَهُمْ، فَسَلَكُوا سَبِيلَ الْمُهَاجِرِينَ، وَاخْتَلَفُوا كَاخْتِلاَفِهِمْ، فَقَالَ ارْتَفِعُوا عَنِّي‏.‏ ثُمَّ قَالَ ادْعُ لِي مَنْ كَانَ هَا هُنَا مِنْ مَشْيَخَةِ قُرَيْشٍ مِنْ مُهَاجِرَةِ الْفَتْحِ‏.‏ فَدَعَوْتُهُمْ، فَلَمْ يَخْتَلِفْ مِنْهُمْ عَلَيْهِ رَجُلاَنِ، فَقَالُوا نَرَى أَنْ تَرْجِعَ بِالنَّاسِ، وَلاَ تُقْدِمَهُمْ عَلَى هَذَا الْوَبَاءِ، فَنَادَى عُمَرُ فِي النَّاسِ، إِنِّي مُصَبِّحٌ عَلَى ظَهْرٍ، فَأَصْبِحُوا عَلَيْهِ‏.‏ قَالَ أَبُو عُبَيْدَةَ بْنُ الْجَرَّاحِ أَفِرَارًا مِنْ قَدَرِ اللَّهِ فَقَالَ عُمَرُ لَوْ غَيْرُكَ قَالَهَا يَا أَبَا عُبَيْدَةَ، نَعَمْ نَفِرُّ مِنْ قَدَرِ اللَّهِ إِلَى قَدَرِ اللَّهِ، أَرَأَيْتَ لَوْ كَانَ لَكَ إِبِلٌ هَبَطَتْ وَادِيًا لَهُ عُدْوَتَانِ، إِحْدَاهُمَا خَصِبَةٌ، وَالأُخْرَى جَدْبَةٌ، أَلَيْسَ إِنْ رَعَيْتَ الْخَصْبَةَ رَعَيْتَهَا بِقَدَرِ اللَّهِ، وَإِنْ رَعَيْتَ الْجَدْبَةَ رَعَيْتَهَا بِقَدَرِ اللَّهِ قَالَ فَجَاءَ عَبْدُ الرَّحْمَنِ بْنُ عَوْفٍ، وَكَانَ مُتَغَيِّبًا فِي بَعْضِ حَاجَتِهِ فَقَالَ إِنَّ عِنْدِي فِي هَذَا عِلْمًا سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِذَا سَمِعْتُمْ بِهِ بِأَرْضٍ فَلاَ تَقْدَمُوا عَلَيْهِ، وَإِذَا وَقَعَ بِأَرْضٍ وَأَنْتُمْ بِهَا فَلاَ تَخْرُجُوا فِرَارًا مِنْهُ ‏"‏‏.‏ قَالَ فَحَمِدَ اللَّهَ عُمَرُ ثُمَّ انْصَرَفَ‏.‏\hadithno{5729}\hadithtrans{Narrated `Abdullah bin `Abbas:`Umar bin Al-Khattab departed for Sham and when he reached Sargh, the commanders of the (Muslim) army, Abu 'Ubaida bin Al-Jarrah and his companions met him and told him that an epidemic had broken out in Sham. `Umar said, "Call for me the early emigrants." So `Umar called them, consulted them and informed them that an epidemic had broken out in Sham. Those people differed in their opinions. Some of them said, "We have come out for a purpose and we do not think that it is proper to give it up," while others said (to `Umar), "You have along with you. other people and the companions of Allah's Messenger (ﷺ) so do not advise that we take them to this epidemic." `Umar said to them, "Leave me now." Then he said, "Call the Ansar for me." I called them and he consulted them and they followed the way of the emigrants and differed as they did. He then said to them, Leave me now," and added, "Call for me the old people of Quraish who emigrated in the year of the Conquest of Mecca." I called them and they gave a unanimous opinion saying, "We advise that you should return with the people and do not take them to that (place) of epidemic." So `Umar made an announcement, "I will ride back to Medina in the morning, so you should do the same." Abu 'Ubaida bin Al-Jarrah said (to `Umar), "Are you running away from what Allah had ordained?" `Umar said, "Would that someone else had said such a thing, O Abu 'Ubaida! Yes, we are running from what Allah had ordained to what Allah has ordained. Don't you agree that if you had camels that went down a valley having two places, one green and the other dry, you would graze them on the green one only if Allah had ordained that, and you would graze them on the dry one only if Allah had ordained that?" At that time `Abdur-Rahman bin `Auf, who had been absent because of some job, came and said, "I have some knowledge about this. I have heard Allah's Messenger (ﷺ) saying, 'If you hear about it (an outbreak of plague) in a land, do not go to it; but if plague breaks out in a country where you are staying, do not run away from it.' " `Umar thanked Allah and returned to Medina}}
\hadithdefcmd{bukhari}{5730}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنِ ابْنِ شِهَابٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَامِرٍ، أَنَّ عُمَرَ، خَرَجَ إِلَى الشَّأْمِ، فَلَمَّا كَانَ بِسَرْغَ بَلَغَهُ أَنَّ الْوَبَاءَ قَدْ وَقَعَ بِالشَّأْمِ، فَأَخْبَرَهُ عَبْدُ الرَّحْمَنِ بْنُ عَوْفٍ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا سَمِعْتُمْ بِهِ بِأَرْضٍ فَلاَ تَقْدَمُوا عَلَيْهِ وَإِذَا وَقَعَ بِأَرْضٍ وَأَنْتُمْ بِهَا فَلاَ تَخْرُجُوا فِرَارًا مِنْهُ ‏"‏‏.‏\hadithno{5730}\hadithtrans{Narrated `Abdullah bin 'Amir:`Umar went to Sham and when he reached Sargh, he got the news that an epidemic (of plague) had broken out in Sham. `Abdur-Rahman bin `Auf told him that Allah's Messenger (ﷺ) said, "If you hear that it (plague) has broken out in a land, do not go to it; but if it breaks out in a land where you are present, do not go out escaping from it}}
\hadithdefcmd{bukhari}{5731}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنْ نُعَيْمٍ الْمُجْمِرِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ يَدْخُلُ الْمَدِينَةَ الْمَسِيحُ وَلاَ الطَّاعُونُ ‏"‏‏.‏\hadithno{5731}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "Neither Messiah (Ad-Dajjal) nor plague will enter Medina}}
\hadithdefcmd{bukhari}{5732}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا عَبْدُ الْوَاحِدِ، حَدَّثَنَا عَاصِمٌ، حَدَّثَتْنِي حَفْصَةُ بِنْتُ سِيرِينَ، قَالَتْ قَالَ لِي أَنَسُ بْنُ مَالِكٍ ـ رضى الله عنه ـ يَحْيَى بِمَا مَاتَ قُلْتُ مِنَ الطَّاعُونِ‏.‏ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الطَّاعُونُ شَهَادَةٌ لِكُلِّ مُسْلِمٍ ‏"‏‏.‏\hadithno{5732}\hadithtrans{Narrated Anas bin Malik:Allah's Messenger (ﷺ) said, "(Death from) plague is martyrdom for every Muslim}}
\hadithdefcmd{bukhari}{5733}{حَدَّثَنَا أَبُو عَاصِمٍ، عَنْ مَالِكٍ، عَنْ سُمَىٍّ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ الْمَبْطُونُ شَهِيدٌ، وَالْمَطْعُونُ شَهِيدٌ ‏"‏‏.‏\hadithno{5733}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "He (a Muslim) who dies of an abdominal disease is a martyr, and he who dies of plague is a martyr}}
\hadithdefcmd{bukhari}{5734}{حَدَّثَنَا إِسْحَاقُ، أَخْبَرَنَا حَبَّانُ، حَدَّثَنَا دَاوُدُ بْنُ أَبِي الْفُرَاتِ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ بُرَيْدَةَ، عَنْ يَحْيَى بْنِ يَعْمَرَ، عَنْ عَائِشَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم أَنَّهَا أَخْبَرَتْنَا أَنَّهَا سَأَلَتْ رَسُولَ اللَّهِ صلى الله عليه وسلم عَنِ الطَّاعُونِ فَأَخْبَرَهَا نَبِيُّ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَنَّهُ كَانَ عَذَابًا يَبْعَثُهُ اللَّهُ عَلَى مَنْ يَشَاءُ، فَجَعَلَهُ اللَّهُ رَحْمَةً لِلْمُؤْمِنِينَ، فَلَيْسَ مِنْ عَبْدٍ يَقَعُ الطَّاعُونُ فَيَمْكُثُ فِي بَلَدِهِ صَابِرًا، يَعْلَمُ أَنَّهُ لَنْ يُصِيبَهُ إِلاَّ مَا كَتَبَ اللَّهُ لَهُ، إِلاَّ كَانَ لَهُ مِثْلُ أَجْرِ الشَّهِيدِ ‏"‏‏.‏ تَابَعَهُ النَّضْرُ عَنْ دَاوُدَ‏.‏\hadithno{5734}\hadithtrans{Narrated `Aisha:(the wife of the Prophet) that she asked Allah's Messenger (ﷺ) about plague, and Allah's Messenger (ﷺ) informed her saying, "Plague was a punishment which Allah used to send on whom He wished, but Allah made it a blessing for the believers. None (among the believers) remains patient in a land in which plague has broken out and considers that nothing will befall him except what Allah has ordained for him, but that Allah will grant him a reward similar to that of a martyr}}
\hadithdefcmd{bukhari}{5735}{حَدَّثَنِي إِبْرَاهِيمُ بْنُ مُوسَى، أَخْبَرَنَا هِشَامٌ، عَنْ مَعْمَرٍ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يَنْفُثُ عَلَى نَفْسِهِ فِي الْمَرَضِ الَّذِي مَاتَ فِيهِ بِالْمُعَوِّذَاتِ، فَلَمَّا ثَقُلَ كُنْتُ أَنْفِثُ عَلَيْهِ بِهِنَّ، وَأَمْسَحُ بِيَدِ نَفْسِهِ لِبَرَكَتِهَا‏.‏ فَسَأَلْتُ الزُّهْرِيَّ كَيْفَ يَنْفِثُ قَالَ كَانَ يَنْفِثُ عَلَى يَدَيْهِ، ثُمَّ يَمْسَحُ بِهِمَا وَجْهَهُ‏.‏\hadithno{5735}\hadithtrans{Narrated `Aisha:During the Prophet's fatal illness, he used to recite the Mu'auwidhat (Surat An-Nas and Surat Al- Falaq) and then blow his breath over his body. When his illness was aggravated, I used to recite those two Suras and blow my breath over him and make him rub his body with his own hand for its blessings." (Ma`mar asked Az-Zuhri: How did the Prophet (ﷺ) use to blow? Az-Zuhri said: He used to blow on his hands and then passed them over his face}}
\hadithdefcmd{bukhari}{5736}{حَدَّثَنِي مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا غُنْدَرٌ، حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي بِشْرٍ، عَنْ أَبِي الْمُتَوَكِّلِ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ ـ رضى الله عنه ـ أَنَّ نَاسًا مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم أَتَوْا عَلَى حَىٍّ مِنْ أَحْيَاءِ الْعَرَبِ فَلَمْ يَقْرُوهُمْ، فَبَيْنَمَا هُمْ كَذَلِكَ إِذْ لُدِغَ سَيِّدُ أُولَئِكَ فَقَالُوا هَلْ مَعَكُمْ مِنْ دَوَاءٍ أَوْ رَاقٍ فَقَالُوا إِنَّكُمْ لَمْ تَقْرُونَا، وَلاَ نَفْعَلُ حَتَّى تَجْعَلُوا لَنَا جُعْلاً‏.‏ فَجَعَلُوا لَهُمْ قَطِيعًا مِنَ الشَّاءِ، فَجَعَلَ يَقْرَأُ بِأُمِّ الْقُرْآنِ، وَيَجْمَعُ بُزَاقَهُ، وَيَتْفِلُ، فَبَرَأَ، فَأَتَوْا بِالشَّاءِ، فَقَالُوا لاَ نَأْخُذُهُ حَتَّى نَسْأَلَ النَّبِيَّ صلى الله عليه وسلم فَسَأَلُوهُ فَضَحِكَ وَقَالَ ‏ "‏ وَمَا أَدْرَاكَ أَنَّهَا رُقْيَةٌ، خُذُوهَا، وَاضْرِبُوا لِي بِسَهْمٍ ‏"‏‏.‏\hadithno{5736}\hadithtrans{Narrated Abu Sa`id Al-Khudri:Some of the companions of the Prophet (ﷺ) came across a tribe amongst the tribes of the Arabs, and that tribe did not entertain them. While they were in that state, the chief of that tribe was bitten by a snake (or stung by a scorpion). They said, (to the companions of the Prophet (ﷺ) ), "Have you got any medicine with you or anybody who can treat with Ruqya?" The Prophet's companions said, "You refuse to entertain us, so we will not treat (your chief) unless you pay us for it." So they agreed to pay them a flock of sheep. One of them (the Prophet's companions) started reciting Surat-al-Fatiha and gathering his saliva and spitting it (at the snake-bite). The patient got cured and his people presented the sheep to them, but they said, "We will not take it unless we ask the Prophet (whether it is lawful)." When they asked him, he smiled and said, "How do you know that Surat-al-Fatiha is a Ruqya? Take it (flock of sheep) and assign a share for me}}
\hadithdefcmd{bukhari}{5737}{حَدَّثَنِي سِيدَانُ بْنُ مُضَارِبٍ أَبُو مُحَمَّدٍ الْبَاهِلِيُّ، حَدَّثَنَا أَبُو مَعْشَرٍ الْبَصْرِيُّ ـ هُوَ صَدُوقٌ ـ يُوسُفُ بْنُ يَزِيدَ الْبَرَّاءُ قَالَ حَدَّثَنِي عُبَيْدُ اللَّهِ بْنُ الأَخْنَسِ أَبُو مَالِكٍ، عَنِ ابْنِ أَبِي مُلَيْكَةَ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ نَفَرًا، مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم مَرُّوا بِمَاءٍ فِيهِمْ لَدِيغٌ ـ أَوْ سَلِيمٌ ـ فَعَرَضَ لَهُمْ رَجُلٌ مِنْ أَهْلِ الْمَاءِ فَقَالَ هَلْ فِيكُمْ مِنْ رَاقٍ إِنَّ فِي الْمَاءِ رَجُلاً لَدِيغًا أَوْ سَلِيمًا‏.‏ فَانْطَلَقَ رَجُلٌ مِنْهُمْ فَقَرَأَ بِفَاتِحَةِ الْكِتَابِ عَلَى شَاءٍ، فَبَرَأَ، فَجَاءَ بِالشَّاءِ إِلَى أَصْحَابِهِ فَكَرِهُوا ذَلِكَ وَقَالُوا أَخَذْتَ عَلَى كِتَابِ اللَّهِ أَجْرًا‏.‏ حَتَّى قَدِمُوا الْمَدِينَةَ فَقَالُوا يَا رَسُولَ اللَّهِ أَخَذَ عَلَى كِتَابِ اللَّهِ أَجْرًا‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ أَحَقَّ مَا أَخَذْتُمْ عَلَيْهِ أَجْرًا كِتَابُ اللَّهِ ‏"‏‏.‏\hadithno{5737}\hadithtrans{Narrated Ibn `Abbas:Some of the companions of the Prophet (ﷺ) passed by some people staying at a place where there was water, and one of those people had been stung by a scorpion. A man from those staying near the water, came and said to the companions of the Prophet, "Is there anyone among you who can do Ruqya as near the water there is a person who has been stung by a scorpion." So one of the Prophet's companions went to him and recited Surat-al-Fatiha for a sheep as his fees. The patient got cured and the man brought the sheep to his companions who disliked that and said, "You have taken wages for reciting Allah's Book." When they arrived at Medina, they said, ' O Allah's Messenger (ﷺ)! (This person) has taken wages for reciting Allah's Book" On that Allah's Messenger (ﷺ) said, "You are most entitled to take wages for doing a Ruqya with Allah's Book}}
\hadithdefcmd{bukhari}{5738}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، أَخْبَرَنَا سُفْيَانُ، قَالَ حَدَّثَنِي مَعْبَدُ بْنُ خَالِدٍ، قَالَ سَمِعْتُ عَبْدَ اللَّهِ بْنَ شَدَّادٍ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ أَمَرَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم أَوْ أَمَرَ أَنْ يُسْتَرْقَى مِنَ الْعَيْنِ‏.‏\hadithno{5738}\hadithtrans{Narrated `Aisha:The Prophet (ﷺ) ordered me or somebody else to do Ruqya (if there was danger) from an evil eye}}
\hadithdefcmd{bukhari}{5739}{حَدَّثَنِي مُحَمَّدُ بْنُ خَالِدٍ، حَدَّثَنَا مُحَمَّدُ بْنُ وَهْبِ بْنِ عَطِيَّةَ الدِّمَشْقِيُّ، حَدَّثَنَا مُحَمَّدُ بْنُ حَرْبٍ، حَدَّثَنَا مُحَمَّدُ بْنُ الْوَلِيدِ الزُّبَيْدِيُّ، أَخْبَرَنَا الزُّهْرِيُّ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، عَنْ زَيْنَبَ ابْنَةِ أَبِي سَلَمَةَ، عَنْ أُمِّ سَلَمَةَ ـ رضى الله عنها ـ أَنَّ النَّبِيَّ صلى الله عليه وسلم رَأَى فِي بَيْتِهَا جَارِيَةً فِي وَجْهِهَا سَفْعَةٌ فَقَالَ ‏ "‏ اسْتَرْقُوا لَهَا، فَإِنَّ بِهَا النَّظْرَةَ ‏"‏‏.‏ وَقَالَ عُقَيْلٌ عَنِ الزُّهْرِيِّ أَخْبَرَنِي عُرْوَةُ عَنِ النَّبِيِّ صلى الله عليه وسلم‏.‏ تَابَعَهُ عَبْدُ اللَّهِ بْنُ سَالِمٍ عَنِ الزُّبَيْدِيِّ‏.‏\hadithno{5739}\hadithtrans{Narrated Um Salama:that the Prophet (ﷺ) saw in her house a girl whose face had a black spot. He said. "She is under the effect of an evil eye; so treat her with a Ruqya}}
\hadithdefcmd{bukhari}{5740}{حَدَّثَنَا إِسْحَاقُ بْنُ نَصْرٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، عَنْ مَعْمَرٍ، عَنْ هَمَّامٍ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ الْعَيْنُ حَقٌّ ‏"‏‏.‏ وَنَهَى عَنِ الْوَشْمِ‏.‏\hadithno{5740}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "The effect of an evil eye is a fact." And he prohibited tattooing}}
\hadithdefcmd{bukhari}{5741}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا عَبْدُ الْوَاحِدِ، حَدَّثَنَا سُلَيْمَانُ الشَّيْبَانِيُّ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ الأَسْوَدِ، عَنْ أَبِيهِ، قَالَ سَأَلْتُ عَائِشَةَ عَنِ الرُّقْيَةِ، مِنَ الْحُمَةِ فَقَالَتْ رَخَّصَ النَّبِيُّ صلى الله عليه وسلم الرُّقْيَةَ مِنْ كُلِّ ذِي حُمَةٍ‏.‏\hadithno{5741}\hadithtrans{Narrated Al-Aswad:I asked `Aisha about treating poisonous stings (a snake-bite or a scorpion sting) with a Ruqya. She said, "The Prophet (ﷺ) allowed the treatment of poisonous sting with Ruqya}}
\hadithdefcmd{bukhari}{5742}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا عَبْدُ الْوَارِثِ، عَنْ عَبْدِ الْعَزِيزِ، قَالَ دَخَلْتُ أَنَا وَثَابِتٌ، عَلَى أَنَسِ بْنِ مَالِكٍ فَقَالَ ثَابِتٌ يَا أَبَا حَمْزَةَ اشْتَكَيْتُ‏.‏ فَقَالَ أَنَسٌ أَلاَ أَرْقِيكَ بِرُقْيَةِ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ بَلَى‏.‏ قَالَ ‏ "‏ اللَّهُمَّ رَبَّ النَّاسِ مُذْهِبَ الْبَاسِ اشْفِ أَنْتَ الشَّافِي لاَ شَافِيَ إِلاَّ أَنْتَ، شِفَاءً لاَ يُغَادِرُ سَقَمًا ‏"‏‏.‏\hadithno{5742}\hadithtrans{Narrated `Abdul `Aziz:Thabit and I went to Anas bin Malik. Thabit said, "O Abu Hamza! I am sick." On that Anas said, "Shall I treat you with the Ruqya of Allah's Messenger (ﷺ)?" Thabit said, "Yes," Anas recited, "O Allah! The Lord of the people, the Remover of trouble! (Please) cure (Heal) (this patient), for You are the Healer. None brings about healing but You; a healing that will leave behind no ailment}}
\hadithdefcmd{bukhari}{5743}{حَدَّثَنَا عَمْرُو بْنُ عَلِيٍّ، حَدَّثَنَا يَحْيَى، حَدَّثَنَا سُفْيَانُ، حَدَّثَنِي سُلَيْمَانُ، عَنْ مُسْلِمٍ، عَنْ مَسْرُوقٍ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يُعَوِّذُ بَعْضَ أَهْلِهِ، يَمْسَحُ بِيَدِهِ الْيُمْنَى وَيَقُولُ ‏ "‏ اللَّهُمَّ رَبَّ النَّاسِ أَذْهِبِ الْبَاسَ، اشْفِهِ وَأَنْتَ الشَّافِي، لاَ شِفَاءَ إِلاَّ شِفَاؤُكَ، شِفَاءً لاَ يُغَادِرُ سَقَمًا ‏"‏‏.‏ قَالَ سُفْيَانُ حَدَّثْتُ بِهِ مَنْصُورًا فَحَدَّثَنِي عَنْ إِبْرَاهِيمَ عَنْ مَسْرُوقٍ عَنْ عَائِشَةَ نَحْوَهُ‏.‏\hadithno{5743}\hadithtrans{Narrated `Aisha:The Prophet (ﷺ) used to treat some of his wives by passing his right hand over the place of ailment and used to say, "O Allah, the Lord of the people! Remove the trouble and heal the patient, for You are the Healer. No healing is of any avail but Yours; healing that will leave behind no ailment}}
\hadithdefcmd{bukhari}{5744}{حَدَّثَنِي أَحْمَدُ بْنُ أَبِي رَجَاءٍ، حَدَّثَنَا النَّضْرُ، عَنْ هِشَامِ بْنِ عُرْوَةَ، قَالَ أَخْبَرَنِي أَبِي، عَنْ عَائِشَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَرْقِي يَقُولُ ‏ "‏ امْسَحِ الْبَاسَ رَبَّ النَّاسِ، بِيَدِكَ الشِّفَاءُ، لاَ كَاشِفَ لَهُ إِلاَّ أَنْتَ ‏"‏‏.‏\hadithno{5744}\hadithtrans{Narrated `Aisha:Allah's Messenger (ﷺ) used to treat with a Ruqya saying, "O the Lord of the people! Remove the trouble The cure is in Your Hands, and there is none except You who can remove it (the disease)}}
\hadithdefcmd{bukhari}{5745}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سُفْيَانُ، قَالَ حَدَّثَنِي عَبْدُ رَبِّهِ بْنُ سَعِيدٍ، عَنْ عَمْرَةَ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يَقُولُ لِلْمَرِيضِ ‏ "‏ بِسْمِ اللَّهِ، تُرْبَةُ أَرْضِنَا‏.‏ بِرِيقَةِ بَعْضِنَا، يُشْفَى سَقِيمُنَا بِإِذْنِ رَبِّنَا ‏"‏‏.‏\hadithno{5745}\hadithtrans{Narrated `Aisha:The Prophet (ﷺ) used to say to the patient, "In the Name of Allah The earth of our land and the saliva of some of us cure our patient}}
\hadithdefcmd{bukhari}{5746}{حَدَّثَنِي صَدَقَةُ بْنُ الْفَضْلِ، أَخْبَرَنَا ابْنُ عُيَيْنَةَ، عَنْ عَبْدِ رَبِّهِ بْنِ سَعِيدٍ، عَنْ عَمْرَةَ، عَنْ عَائِشَةَ، قَالَتْ كَانَ النَّبِيُّ صلى الله عليه وسلم يَقُولُ فِي الرُّقْيَةِ ‏ "‏ تُرْبَةُ أَرْضِنَا، وَرِيقَةُ بَعْضِنَا، يُشْفَى سَقِيمُنَا، بِإِذْنِ رَبِّنَا ‏"‏‏.‏\hadithno{5746}\hadithtrans{Narrated `Aisha:Allah's Messenger (ﷺ) used to read in his Ruqya, "In the Name of Allah" The earth of our land and the saliva of some of us cure our patient with the permission of our Lord." with a slight shower of saliva) while treating with a Ruqya}}
\hadithdefcmd{bukhari}{5747}{حَدَّثَنَا خَالِدُ بْنُ مَخْلَدٍ، حَدَّثَنَا سُلَيْمَانُ، عَنْ يَحْيَى بْنِ سَعِيدٍ، قَالَ سَمِعْتُ أَبَا سَلَمَةَ، قَالَ سَمِعْتُ أَبَا قَتَادَةَ، يَقُولُ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏ الرُّؤْيَا مِنَ اللَّهِ، وَالْحُلْمُ مِنَ الشَّيْطَانِ، فَإِذَا رَأَى أَحَدُكُمْ شَيْئًا يَكْرَهُهُ فَلْيَنْفِثْ حِينَ يَسْتَيْقِظُ ثَلاَثَ مَرَّاتٍ وَيَتَعَوَّذْ مِنْ شَرِّهَا، فَإِنَّهَا لاَ تَضُرُّهُ ‏"‏‏.‏ وَقَالَ أَبُو سَلَمَةَ وَإِنْ كُنْتُ لأَرَى الرُّؤْيَا أَثْقَلَ عَلَىَّ مِنَ الْجَبَلِ، فَمَا هُوَ إِلاَّ أَنْ سَمِعْتُ هَذَا الْحَدِيثَ فَمَا أُبَالِيهَا‏.‏\hadithno{5747}\hadithtrans{Narrated Abu Qatada:I heard the Prophet (ﷺ) saying, "A good dream is from Allah, and a bad dream is from Satan. So if anyone of you sees (in a dream) something he dislikes, when he gets up he should blow thrice (on his left side) and seek refuge with Allah from its evil for then it will not harm him}}
\hadithdefcmd{bukhari}{5748}{حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ عَبْدِ اللَّهِ الأُوَيْسِيُّ، حَدَّثَنَا سُلَيْمَانُ، عَنْ يُونُسَ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا أَوَى إِلَى فِرَاشِهِ نَفَثَ فِي كَفَّيْهِ بِقُلْ هُوَ اللَّهُ أَحَدٌ وَبِالْمُعَوِّذَتَيْنِ جَمِيعًا، ثُمَّ يَمْسَحُ بِهِمَا وَجْهَهُ، وَمَا بَلَغَتْ يَدَاهُ مِنْ جَسَدِهِ‏.‏ قَالَتْ عَائِشَةُ فَلَمَّا اشْتَكَى كَانَ يَأْمُرُنِي أَنْ أَفْعَلَ ذَلِكَ بِهِ‏.‏ قَالَ يُونُسُ كُنْتُ أَرَى ابْنَ شِهَابٍ يَصْنَعُ ذَلِكَ إِذَا أَتَى إِلَى فِرَاشِهِ‏.‏\hadithno{5748}\hadithtrans{Narrated `Aisha:Whenever Allah's Messenger (ﷺ) went to bed, he used to recite Surat-al-Ikhlas, Surat-al-Falaq and Surat-an- Nas and then blow on his palms and pass them over his face and those parts of his body that his hands could reach. And when he fell ill, he used to order me to do like that for him}}
\hadithdefcmd{bukhari}{5749}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ أَبِي بِشْرٍ، عَنْ أَبِي الْمُتَوَكِّلِ، عَنْ أَبِي سَعِيدٍ، أَنَّ رَهْطًا، مِنْ أَصْحَابِ رَسُولِ اللَّهِ صلى الله عليه وسلم انْطَلَقُوا فِي سَفْرَةٍ سَافَرُوهَا، حَتَّى نَزَلُوا بِحَىٍّ مِنْ أَحْيَاءِ الْعَرَبِ فَاسْتَضَافُوهُمْ، فَأَبَوْا أَنْ يُضَيِّفُوهُمْ، فَلُدِغَ سَيِّدُ ذَلِكَ الْحَىِّ، فَسَعَوْا لَهُ بِكُلِّ شَىْءٍ لاَ يَنْفَعُهُ شَىْءٌ، فَقَالَ بَعْضُهُمْ لَوْ أَتَيْتُمْ هَؤُلاَءِ الرَّهْطَ الَّذِينَ قَدْ نَزَلُوا بِكُمْ، لَعَلَّهُ أَنْ يَكُونَ عِنْدَ بَعْضِهِمْ شَىْءٌ‏.‏ فَأَتَوْهُمْ فَقَالُوا يَا أَيُّهَا الرَّهْطُ إِنَّ سَيِّدَنَا لُدِغَ، فَسَعَيْنَا لَهُ بِكُلِّ شَىْءٍ، لاَ يَنْفَعُهُ شَىْءٌ، فَهَلْ عِنْدَ أَحَدٍ مِنْكُمْ شَىْءٌ فَقَالَ بَعْضُهُمْ نَعَمْ، وَاللَّهِ إِنِّي لَرَاقٍ، وَلَكِنْ وَاللَّهِ لَقَدِ اسْتَضَفْنَاكُمْ فَلَمْ تُضَيِّفُونَا، فَمَا أَنَا بِرَاقٍ لَكُمْ حَتَّى تَجْعَلُوا لَنَا جُعْلاً‏.‏ فَصَالَحُوهُمْ عَلَى قَطِيعٍ مِنَ الْغَنَمِ، فَانْطَلَقَ فَجَعَلَ يَتْفُلُ وَيَقْرَأُ ‏\{‏الْحَمْدُ لِلَّهِ رَبِّ الْعَالَمِينَ‏\}‏ حَتَّى لَكَأَنَّمَا نُشِطَ مِنْ عِقَالٍ، فَانْطَلَقَ يَمْشِي مَا بِهِ قَلَبَةٌ‏.‏ قَالَ فَأَوْفَوْهُمْ جُعْلَهُمُ الَّذِي صَالَحُوهُمْ عَلَيْهِ، فَقَالَ بَعْضُهُمُ اقْسِمُوا‏.‏ فَقَالَ الَّذِي رَقَى لاَ تَفْعَلُوا حَتَّى نَأْتِيَ رَسُولَ اللَّهِ صلى الله عليه وسلم فَنَذْكُرَ لَهُ الَّذِي كَانَ، فَنَنْظُرَ مَا يَأْمُرُنَا‏.‏ فَقَدِمُوا عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَذَكَرُوا لَهُ فَقَالَ ‏"‏ وَمَا يُدْرِيكَ أَنَّهَا رُقْيَةٌ أَصَبْتُمُ اقْسِمُوا وَاضْرِبُوا لِي مَعَكُمْ بِسَهْمٍ ‏"‏‏.‏\hadithno{5749}\hadithtrans{Narrated Abu Sa`id:A group of the companions of Allah's Messenger (ﷺ) proceeded on a journey till they dismounted near one of the Arab tribes and requested them to entertain them as their guests, but they (the tribe people) refused to entertain them. Then the chief of that tribe was bitten by a snake (or stung by a scorpion) and he was given all sorts of treatment, but all in vain. Some of them said, "Will you go to the group (those travelers) who have dismounted near you and see if one of them has something useful?" They came to them and said, "O the group! Our leader has been bitten by a snake (or stung by a scorpion) and we have treated him with everything but nothing benefited him Has anyone of you anything useful?" One of them replied, "Yes, by Allah, I know how to treat with a Ruqya. But. by Allah, we wanted you to receive us as your guests but you refused. I will not treat your patient with a Ruqya till you fix for us something as wages." Consequently they agreed to give those travellers a flock of sheep. The man went with them (the people of the tribe) and started spitting (on the bite) and reciting Surat-al-Fatiha till the patient was healed and started walking as if he had not been sick. When the tribe people paid them their wages they had agreed upon, some of them (the Prophet's companions) said, "Distribute (the sheep)." But the one who treated with the Ruqya said, "Do not do that till we go to Allah's Apostle and mention to him what has happened, and see what he will order us." So they came to Allah's Messenger (ﷺ) and mentioned the story to him and he said, "How do you know that Surat-al-Fatiha is a Ruqya? You have done the right thing. Divide (what you have got) and assign for me a share with you}}
\hadithdefcmd{bukhari}{5750}{حَدَّثَنِي عَبْدُ اللَّهِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَحْيَى، عَنْ سُفْيَانَ، عَنِ الأَعْمَشِ، عَنْ مُسْلِمٍ، عَنْ مَسْرُوقٍ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ كَانَ النَّبِيُّ صلى الله عليه وسلم يُعَوِّذُ بَعْضَهُمْ يَمْسَحُهُ بِيَمِينِهِ ‏ "‏ أَذْهِبِ الْبَاسَ رَبَّ النَّاسِ، وَاشْفِ أَنْتَ الشَّافِي، لاَ شِفَاءَ إِلاَّ شِفَاؤُكَ، شِفَاءً لاَ يُغَادِرُ سَقَمًا ‏"‏‏.‏ فَذَكَرْتُهُ لِمَنْصُورٍ فَحَدَّثَنِي عَنْ إِبْرَاهِيمَ عَنْ مَسْرُوقٍ عَنْ عَائِشَةَ بِنَحْوِهِ‏.‏\hadithno{5750}\hadithtrans{Narrated `Aisha:The Prophet (ﷺ) used to treat some of his wives by passing his right hand over the place of ailment and used to say, "O Lord of the people! Remove the difficulty and bring about healing as You are the Healer. There is no healing but Your Healing, a healing that will leave no ailment}}
\hadithdefcmd{bukhari}{5751}{حَدَّثَنِي عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ الْجُعْفِيُّ، حَدَّثَنَا هِشَامٌ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يَنْفِثُ عَلَى نَفْسِهِ فِي مَرَضِهِ الَّذِي قُبِضَ فِيهِ بِالْمُعَوِّذَاتِ، فَلَمَّا ثَقُلَ كُنْتُ أَنَا أَنْفِثُ عَلَيْهِ بِهِنَّ، فَأَمْسَحُ بِيَدِ نَفْسِهِ لِبَرَكَتِهَا‏.‏ فَسَأَلْتُ ابْنَ شِهَابٍ كَيْفَ كَانَ يَنْفِثُ قَالَ يَنْفِثُ عَلَى يَدَيْهِ، ثُمَّ يَمْسَحُ بِهِمَا وَجْهَهُ‏.‏\hadithno{5751}\hadithtrans{Narrated `Aisha:The Prophet, during his fatal ailment used to blow (on his hands and pass them) over his body while reciting the Mu'auwidhat (Surat-an-Nas and Surat-al-Falaq). When his disease got aggravated, I used to recite them for him and blow (on his hands) and let him pass his hands over his body because of its blessing. (Ma`mar asked Ibn Shihab: How did he use to do Nafth? He said: He used to blow on his hands and then pass them over his face)}}
\hadithdefcmd{bukhari}{5752}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا حُصَيْنُ بْنُ نُمَيْرٍ، عَنْ حُصَيْنِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ خَرَجَ عَلَيْنَا النَّبِيُّ صلى الله عليه وسلم يَوْمًا فَقَالَ ‏"‏ عُرِضَتْ عَلَىَّ الأُمَمُ فَجَعَلَ يَمُرُّ النَّبِيُّ مَعَهُ الرَّجُلُ وَالنَّبِيُّ مَعَهُ الرَّجُلاَنِ، وَالنَّبِيُّ مَعَهُ الرَّهْطُ، وَالنَّبِيُّ لَيْسَ مَعَهُ أَحَدٌ، وَرَأَيْتُ سَوَادًا كَثِيرًا سَدَّ الأُفُقَ فَرَجَوْتُ أَنْ يَكُونَ أُمَّتِي، فَقِيلَ هَذَا مُوسَى وَقَوْمُهُ‏.‏ ثُمَّ قِيلَ لِي انْظُرْ‏.‏ فَرَأَيْتُ سَوَادًا كَثِيرًا سَدَّ الأُفُقَ فَقِيلَ لِي انْظُرْ هَكَذَا وَهَكَذَا‏.‏ فَرَأَيْتُ سَوَادًا كَثِيرًا سَدَّ الأُفُقَ فَقِيلَ هَؤُلاَءِ أُمَّتُكَ، وَمَعَ هَؤُلاَءِ سَبْعُونَ أَلْفًا يَدْخُلُونَ الْجَنَّةَ بِغَيْرِ حِسَابٍ ‏"‏‏.‏ فَتَفَرَّقَ النَّاسُ وَلَمْ يُبَيَّنْ لَهُمْ، فَتَذَاكَرَ أَصْحَابُ النَّبِيِّ صلى الله عليه وسلم فَقَالُوا أَمَّا نَحْنُ فَوُلِدْنَا فِي الشِّرْكِ، وَلَكِنَّا آمَنَّا بِاللَّهِ وَرَسُولِهِ، وَلَكِنْ هَؤُلاَءِ هُمْ أَبْنَاؤُنَا، فَبَلَغَ النَّبِيَّ صلى الله عليه وسلم فَقَالَ ‏"‏ هُمُ الَّذِينَ لاَ يَتَطَيَّرُونَ، وَلاَ يَسْتَرْقُونَ، وَلاَ يَكْتَوُونَ، وَعَلَى رَبِّهِمْ يَتَوَكَّلُونَ ‏"‏‏.‏ فَقَامَ عُكَّاشَةُ بْنُ مِحْصَنٍ فَقَالَ أَمِنْهُمْ أَنَا يَا رَسُولَ اللَّهِ قَالَ ‏"‏ نَعَمْ ‏"‏‏.‏ فَقَامَ آخَرُ فَقَالَ أَمِنْهُمْ أَنَا فَقَالَ ‏"‏ سَبَقَكَ بِهَا عُكَّاشَةُ ‏"‏‏.‏\hadithno{5752}\hadithtrans{Narrated Ibn `Abbas:The Prophet (ﷺ) once came out to us and said, "Some nations were displayed before me. A prophet would pass in front of me with one man, and another with two men, and another with a group of people. and another with nobody with him. Then I saw a great crowd covering the horizon and I wished that they were my followers, but it was said to me, 'This is Moses and his followers.' Then it was said to me, 'Look'' I looked and saw a big gathering with a large number of people covering the horizon. It was said, "Look this way and that way.' So I saw a big crowd covering the horizon. Then it was said to me, "These are your followers, and among them there are 70,000 who will enter Paradise without (being asked about their) accounts. " Then the people dispersed and the Prophet (ﷺ) did not tell who those 70,000 were. So the companions of the Prophet (ﷺ) started talking about that and some of them said, "As regards us, we were born in the era of heathenism, but then we believed in Allah and His Apostle . We think however, that these (70,000) are our offspring." That talk reached the Prophet (ﷺ) who said, "These (70,000) are the people who do not draw an evil omen from (birds) and do not get treated by branding themselves and do not treat with Ruqya, but put their trust (only) in their Lord." then 'Ukasha bin Muhsin got up and said, "O Allah's Messenger (ﷺ)! Am I one of those (70,000)?" The Prophet (ﷺ) said, "Yes." Then another person got up and said, "Am I one of them?" The Prophet (ﷺ) said, " 'Ukasha has anticipated you}}
\hadithdefcmd{bukhari}{5753}{حَدَّثَنِي عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، حَدَّثَنَا عُثْمَانُ بْنُ عُمَرَ، حَدَّثَنَا يُونُسُ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمٍ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ عَدْوَى وَلاَ طِيَرَةَ، وَالشُّؤْمُ فِي ثَلاَثٍ فِي الْمَرْأَةِ، وَالدَّارِ، وَالدَّابَّةِ ‏"‏‏.‏\hadithno{5753}\hadithtrans{Narrated `Abdullah bin `Umar:Allah's Messenger (ﷺ) said, "There is neither 'Adwa (no contagious disease is conveyed to others without Allah's permission) nor Tiyara, but an evil omen may be in three a woman, a house or an animal}}
\hadithdefcmd{bukhari}{5754}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي عُبَيْدُ اللَّهِ بْنُ عَبْدِ اللَّهِ بْنِ عُتْبَةَ، أَنَّ أَبَا هُرَيْرَةَ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ لاَ طِيَرَةَ، وَخَيْرُهَا الْفَأْلُ ‏"‏‏.‏ قَالُوا وَمَا الْفَأْلُ قَالَ ‏"‏ الْكَلِمَةُ الصَّالِحَةُ يَسْمَعُهَا أَحَدُكُمْ ‏"‏‏.‏\hadithno{5754}\hadithtrans{Narrated Abu Huraira:I heard Allah's Messenger (ﷺ) saying, "There is no Tiyara, and the best omen is the Fal." They asked, "What is the Fal?" He said, "A good word that one of you hears (and takes as a good omen)}}
\hadithdefcmd{bukhari}{5755}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، أَخْبَرَنَا هِشَامٌ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ لاَ طِيَرَةَ، وَخَيْرُهَا الْفَأْلُ ‏"‏‏.‏ قَالَ وَمَا الْفَأْلُ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ الْكَلِمَةُ الصَّالِحَةُ يَسْمَعُهَا أَحَدُكُمْ ‏"‏‏.‏\hadithno{5755}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "There is no Tiyara and the best omen is the Fal," Somebody said, "What is the Fal, O Allah's Messenger (ﷺ)?" He said, "A good word that one of you hears (and takes as a good omen)}}
\hadithdefcmd{bukhari}{5756}{حَدَّثَنَا مُسْلِمُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا هِشَامٌ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ عَدْوَى وَلاَ طِيَرَةَ، وَيُعْجِبُنِي الْفَأْلُ الصَّالِحُ، الْكَلِمَةُ الْحَسَنَةُ ‏"‏‏.‏\hadithno{5756}\hadithtrans{Narrated Anas:The Prophet (ﷺ) said, "No 'Adwa (no contagious disease is conveyed to others without Allah's permission), nor Tiyara, but I like the good Fal, i.e., the good word}}
\hadithdefcmd{bukhari}{5757}{حَدَّثَنَا مُحَمَّدُ بْنُ الْحَكَمِ، حَدَّثَنَا النَّضْرُ، أَخْبَرَنَا إِسْرَائِيلُ، أَخْبَرَنَا أَبُو حَصِينٍ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ عَدْوَى، وَلاَ طِيَرَةَ، وَلاَ هَامَةَ، وَلاَ صَفَرَ ‏"‏‏.‏\hadithno{5757}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "There is no 'Adwa, nor Tiyara, nor Hama, nor Safar}}
\hadithdefcmd{bukhari}{5758}{حَدَّثَنَا سَعِيدُ بْنُ عُفَيْرٍ، حَدَّثَنَا اللَّيْثُ، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ خَالِدٍ، عَنِ ابْنِ شِهَابٍ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَضَى فِي امْرَأَتَيْنِ مِنْ هُذَيْلٍ اقْتَتَلَتَا، فَرَمَتْ إِحْدَاهُمَا الأُخْرَى بِحَجَرٍ، فَأَصَابَ بَطْنَهَا وَهْىَ حَامِلٌ، فَقَتَلَتْ وَلَدَهَا الَّذِي فِي بَطْنِهَا فَاخْتَصَمُوا إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَضَى أَنَّ دِيَةَ مَا فِي بَطْنِهَا غُرَّةٌ عَبْدٌ أَوْ أَمَةٌ، فَقَالَ وَلِيُّ الْمَرْأَةِ الَّتِي غَرِمَتْ كَيْفَ أَغْرَمُ يَا رَسُولَ اللَّهِ مَنْ لاَ شَرِبَ، وَلاَ أَكَلَ، وَلاَ نَطَقَ، وَلاَ اسْتَهَلَّ، فَمِثْلُ ذَلِكَ يُطَلّ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ إِنَّمَا هَذَا مِنْ إِخْوَانِ الْكُهَّانِ ‏"‏‏.‏\hadithno{5758}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) gave his verdict about two ladies of the Hudhail tribe who had fought each other and one of them had hit the other with a stone. The stone hit her `Abdomen and as she was pregnant, the blow killed the child in her womb. They both filed their case with the Prophet (ﷺ) and he judged that the blood money for what was in her womb. was a slave or a female slave. The guardian of the lady who was fined said, "O Allah's Messenger (ﷺ)! Shall I be fined for a creature that has neither drunk nor eaten, neither spoke nor cried? A case like that should be nullified." On that the Prophet (ﷺ) said, "This is one of the brothers of soothsayers}}
\hadithdefcmd{bukhari}{5760}{حَدَّثَنَا قُتَيْبَةُ، عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ أَنَّ امْرَأَتَيْنِ، رَمَتْ إِحْدَاهُمَا الأُخْرَى بِحَجَرٍ فَطَرَحَتْ جَنِينَهَا، فَقَضَى فِيهِ النَّبِيُّ صلى الله عليه وسلم بِغُرَّةٍ عَبْدٍ أَوْ وَلِيدَةٍ‏.‏ وَعَنِ ابْنِ شِهَابٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَضَى فِي الْجَنِينِ يُقْتَلُ فِي بَطْنِ أُمِّهِ بِغُرَّةٍ عَبْدٍ أَوْ وَلِيدَةٍ‏.‏ فَقَالَ الَّذِي قُضِيَ عَلَيْهِ كَيْفَ أَغْرَمُ مَنْ لاَ أَكَلَ، وَلاَ شَرِبَ، وَلاَ نَطَقَ، وَلاَ اسْتَهَلَّ، وَمِثْلُ ذَلِكَ بَطَلْ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّمَا هَذَا مِنْ إِخْوَانِ الْكُهَّانِ ‏"‏‏.‏\hadithno{5760}\hadithtrans{Narrated Abu Huraira:Two ladies (had a fight) and one of them hit the other with a stone on the `Abdomen and caused her to abort. The Prophet (ﷺ) judged that the victim be given either a slave or a female slave (as blood-money). Narrated Ibn Shihab: Sa`id bin Al-Musayyab said, "Allah's Messenger (ﷺ) judged that in case of child killed in the womb of its mother, the offender should give the mother a slave or a female slave in recompense The offender said, How can I be fined for killing one who neither ate nor drank, neither spoke nor cried: a case like that should be denied ' On that Allah's Messenger (ﷺ) said 'He is one of the brothers of the foretellers}}
\hadithdefcmd{bukhari}{5761}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، حَدَّثَنَا ابْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي بَكْرِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ الْحَارِثِ، عَنْ أَبِي مَسْعُودٍ، قَالَ نَهَى النَّبِيُّ صلى الله عليه وسلم عَنْ ثَمَنِ الْكَلْبِ، وَمَهْرِ الْبَغِيِّ، وَحُلْوَانِ الْكَاهِنِ‏.‏\hadithno{5761}\hadithtrans{Narrated Abu Mas`ud:The Prophet (ﷺ) forbade the utilization of the price of a dog, the earnings of prostitute and the earnings of a foreteller}}
\hadithdefcmd{bukhari}{5762}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا هِشَامُ بْنُ يُوسُفَ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ يَحْيَى بْنِ عُرْوَةَ بْنِ الزُّبَيْرِ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ سَأَلَ رَسُولَ اللَّهِ صلى الله عليه وسلم نَاسٌ عَنِ الْكُهَّانِ‏.‏ فَقَالَ ‏"‏ لَيْسَ بِشَىْءٍ ‏"‏‏.‏ فَقَالُوا يَا رَسُولَ اللَّهِ إِنَّهُمْ يُحَدِّثُونَا أَحْيَانًا بِشَىْءٍ فَيَكُونُ حَقًّا‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ تِلْكَ الْكَلِمَةُ مِنَ الْحَقِّ، يَخْطَفُهَا مِنَ الْجِنِّيِّ، فَيَقُرُّهَا فِي أُذُنِ وَلِيِّهِ، فَيَخْلِطُونَ مَعَهَا مِائَةَ كَذْبَةٍ ‏"‏‏.‏ قَالَ عَلِيٌّ قَالَ عَبْدُ الرَّزَّاقِ مُرْسَلٌ، الْكَلِمَةُ مِنَ الْحَقِّ‏.‏ ثُمَّ بَلَغَنِي أَنَّهُ أَسْنَدَهُ بَعْدَهُ‏.‏\hadithno{5762}\hadithtrans{Narrated `Aisha:Some people asked Allah's Messenger (ﷺ) about the fore-tellers He said. ' They are nothing" They said, 'O Allah's Messenger (ﷺ)! Sometimes they tell us of a thing which turns out to be true." Allah's Messenger (ﷺ) said, "A Jinn snatches that true word and pours it Into the ear of his friend (the fore-teller) (as one puts something into a bottle) The foreteller then mixes with that word one hundred lies}}
\hadithdefcmd{bukhari}{5763}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ مُوسَى، أَخْبَرَنَا عِيسَى بْنُ يُونُسَ، عَنْ هِشَامٍ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ سَحَرَ رَسُولَ اللَّهِ صلى الله عليه وسلم رَجُلٌ مِنْ بَنِي زُرَيْقٍ يُقَالُ لَهُ لَبِيدُ بْنُ الأَعْصَمِ، حَتَّى كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُخَيَّلُ إِلَيْهِ أَنَّهُ يَفْعَلُ الشَّىْءَ وَمَا فَعَلَهُ، حَتَّى إِذَا كَانَ ذَاتَ يَوْمٍ أَوْ ذَاتَ لَيْلَةٍ وَهْوَ عِنْدِي لَكِنَّهُ دَعَا وَدَعَا ثُمَّ قَالَ ‏"‏ يَا عَائِشَةُ، أَشَعَرْتِ أَنَّ اللَّهَ أَفْتَانِي فِيمَا اسْتَفْتَيْتُهُ فِيهِ، أَتَانِي رَجُلاَنِ فَقَعَدَ أَحَدُهُمَا عِنْدَ رَأْسِي، وَالآخَرُ عِنْدَ رِجْلَىَّ، فَقَالَ أَحَدُهُمَا لِصَاحِبِهِ مَا وَجَعُ الرَّجُلِ فَقَالَ مَطْبُوبٌ‏.‏ قَالَ مَنْ طَبَّهُ قَالَ لَبِيدُ بْنُ الأَعْصَمِ‏.‏ قَالَ فِي أَىِّ شَىْءٍ قَالَ فِي مُشْطٍ وَمُشَاطَةٍ، وَجُفِّ طَلْعِ نَخْلَةٍ ذَكَرٍ‏.‏ قَالَ وَأَيْنَ هُوَ قَالَ فِي بِئْرِ ذَرْوَانَ ‏"‏‏.‏ فَأَتَاهَا رَسُولُ اللَّهِ صلى الله عليه وسلم فِي نَاسٍ مِنْ أَصْحَابِهِ فَجَاءَ فَقَالَ ‏"‏ يَا عَائِشَةُ كَأَنَّ مَاءَهَا نُقَاعَةُ الْحِنَّاءِ، أَوْ كَأَنَّ رُءُوسَ نَخْلِهَا رُءُوسُ الشَّيَاطِينِ ‏"‏‏.‏ قُلْتُ يَا رَسُولَ اللَّهِ أَفَلاَ أَسْتَخْرِجُهُ قَالَ ‏"‏ قَدْ عَافَانِي اللَّهُ، فَكَرِهْتُ أَنْ أُثَوِّرَ عَلَى النَّاسِ فِيهِ شَرًّا ‏"‏‏.‏ فَأَمَرَ بِهَا فَدُفِنَتْ‏.‏ تَابَعَهُ أَبُو أُسَامَةَ وَأَبُو ضَمْرَةَ وَابْنُ أَبِي الزِّنَادِ عَنْ هِشَامٍ‏.‏ وَقَالَ اللَّيْثُ وَابْنُ عُيَيْنَةَ عَنْ هِشَامٍ فِي مُشْطٍ وَمُشَاقَةٍ‏.‏ يُقَالُ الْمُشَاطَةُ مَا يَخْرُجُ مِنَ الشَّعَرِ إِذَا مُشِطَ، وَالْمُشَاقَةُ مِنْ مُشَاقَةِ الْكَتَّانِ‏.‏\hadithno{5763}\hadithtrans{Narrated `Aisha:A man called Labid bin al-A'sam from the tribe of Bani Zaraiq worked magic on Allah's Messenger (ﷺ) till Allah's Messenger (ﷺ) started imagining that he had done a thing that he had not really done. One day or one night he was with us, he invoked Allah and invoked for a long period, and then said, "O `Aisha! Do you know that Allah has instructed me concerning the matter I have asked him about? Two men came to me and one of them sat near my head and the other near my feet. One of them said to his companion, "What is the disease of this man?" The other replied, "He is under the effect of magic.' The first one asked, 'Who has worked the magic on him?' The other replied, "Labid bin Al-A'sam.' The first one asked, 'What material did he use?' The other replied, 'A comb and the hairs stuck to it and the skin of pollen of a male date palm.' The first one asked, 'Where is that?' The other replied, '(That is) in the well of Dharwan;' " So Allah's Messenger (ﷺ) along with some of his companions went there and came back saying, "O `Aisha, the color of its water is like the infusion of Henna leaves. The tops of the date-palm trees near it are like the heads of the devils." I asked. "O Allah's Messenger (ﷺ)? Why did you not show it (to the people)?" He said, "Since Allah cured me, I disliked to let evil spread among the people." Then he ordered that the well be filled up with earth}}
\hadithdefcmd{bukhari}{5764}{حَدَّثَنِي عَبْدُ الْعَزِيزِ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنِي سُلَيْمَانُ، عَنْ ثَوْرِ بْنِ زَيْدٍ، عَنْ أَبِي الْغَيْثِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ اجْتَنِبُوا الْمُوبِقَاتِ الشِّرْكُ بِاللَّهِ، وَالسِّحْرُ ‏"‏‏.‏\hadithno{5764}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "Avoid the Mubiqat, i.e., shirk and witchcraft}}
\hadithdefcmd{bukhari}{5765}{حَدَّثَنِي عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، قَالَ سَمِعْتُ ابْنَ عُيَيْنَةَ، يَقُولُ أَوَّلُ مَنْ حَدَّثَنَا بِهِ ابْنُ جُرَيْجٍ، يَقُولُ حَدَّثَنِي آلُ، عُرْوَةَ عَنْ عُرْوَةَ، فَسَأَلْتُ هِشَامًا عَنْهُ فَحَدَّثَنَا عَنْ أَبِيهِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم سُحِرَ حَتَّى كَانَ يَرَى أَنَّهُ يَأْتِي النِّسَاءَ وَلاَ يَأْتِيهِنَّ‏.‏ قَالَ سُفْيَانُ وَهَذَا أَشَدُّ مَا يَكُونُ مِنَ السِّحْرِ إِذَا كَانَ كَذَا‏.‏ فَقَالَ ‏"‏ يَا عَائِشَةُ أَعَلِمْتِ أَنَّ اللَّهَ قَدْ أَفْتَانِي فِيمَا اسْتَفْتَيْتُهُ فِيهِ، أَتَانِي رَجُلاَنِ فَقَعَدَ أَحَدُهُمَا عِنْدَ رَأْسِي، وَالآخَرُ عِنْدَ رِجْلَىَّ، فَقَالَ الَّذِي عِنْدَ رَأْسِي لِلآخَرِ مَا بَالُ الرَّجُلِ قَالَ مَطْبُوبٌ‏.‏ قَالَ وَمَنْ طَبَّهُ قَالَ لَبِيدُ بْنُ أَعْصَمَ، رَجُلٌ مِنْ بَنِي زُرَيْقٍ حَلِيفٌ لِيَهُودَ، كَانَ مُنَافِقًا‏.‏ قَالَ وَفِيمَ قَالَ فِي مُشْطٍ وَمُشَاقَةٍ‏.‏ قَالَ وَأَيْنَ قَالَ فِي جُفِّ طَلْعَةٍ ذَكَرٍ، تَحْتَ رَعُوفَةٍ، فِي بِئْرِ ذَرْوَانَ ‏"‏‏.‏ قَالَتْ فَأَتَى النَّبِيُّ صلى الله عليه وسلم الْبِئْرَ حَتَّى اسْتَخْرَجَهُ فَقَالَ ‏"‏ هَذِهِ الْبِئْرُ الَّتِي أُرِيتُهَا، وَكَأَنَّ مَاءَهَا نُقَاعَةُ الْحِنَّاءِ، وَكَأَنَّ نَخْلَهَا رُءُوسُ الشَّيَاطِينِ ‏"‏‏.‏ قَالَ فَاسْتُخْرِجَ، قَالَتْ فَقُلْتُ أَفَلاَ أَىْ تَنَشَّرْتَ‏.‏ فَقَالَ ‏"‏ أَمَا وَاللَّهِ فَقَدْ شَفَانِي، وَأَكْرَهُ أَنْ أُثِيرَ عَلَى أَحَدٍ مِنَ النَّاسِ شَرًّا ‏"‏‏.‏\hadithno{5765}\hadithtrans{Narrated Aisha:Magic was worked on Allah's Messenger (ﷺ) so that he used to think that he had sexual relations with his wives while he actually had not (Sufyan said: That is the hardest kind of magic as it has such an effect). Then one day he said, "O `Aisha do you know that Allah has instructed me concerning the matter I asked Him about? Two men came to me and one of them sat near my head and the other sat near my feet. The one near my head asked the other. What is wrong with this man?' The latter replied the is under the effect of magic The first one asked, Who has worked magic on him?' The other replied Labid bin Al-A'sam, a man from Bani Zuraiq who was an ally of the Jews and was a hypocrite.' The first one asked, What material did he use)?' The other replied, 'A comb and the hair stuck to it.' The first one asked, 'Where (is that)?' The other replied. 'In a skin of pollen of a male date palm tree kept under a stone in the well of Dharwan' '' So the Prophet (ﷺ) went to that well and took out those things and said "That was the well which was shown to me (in a dream) Its water looked like the infusion of Henna leaves and its date-palm trees looked like the heads of devils." The Prophet (ﷺ) added, "Then that thing was taken out' I said (to the Prophet (ﷺ) ) "Why do you not treat yourself with Nashra?" He said, "Allah has cured me; I dislike to let evil spread among my people}}
\hadithdefcmd{bukhari}{5766}{حَدَّثَنَا عُبَيْدُ بْنُ إِسْمَاعِيلَ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ هِشَامٍ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ سُحِرَ النَّبِيُّ صلى الله عليه وسلم حَتَّى إِنَّهُ لَيُخَيَّلُ إِلَيْهِ أَنَّهُ يَفْعَلُ الشَّىْءَ وَمَا فَعَلَهُ، حَتَّى إِذَا كَانَ ذَاتَ يَوْمٍ وَهْوَ عِنْدِي دَعَا اللَّهَ وَدَعَاهُ، ثُمَّ قَالَ ‏"‏ أَشَعَرْتِ يَا عَائِشَةُ أَنَّ اللَّهَ قَدْ أَفْتَانِي فِيمَا اسْتَفْتَيْتُهُ فِيهِ ‏"‏‏.‏ قُلْتُ وَمَا ذَاكَ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ جَاءَنِي رَجُلاَنِ، فَجَلَسَ أَحَدُهُمَا عِنْدَ رَأْسِي وَالآخَرُ عِنْدَ رِجْلَىَّ، ثُمَّ قَالَ أَحَدُهُمَا لِصَاحِبِهِ مَا وَجَعُ الرَّجُلِ قَالَ مَطْبُوبٌ‏.‏ قَالَ وَمَنْ طَبَّهُ قَالَ لَبِيدُ بْنُ الأَعْصَمِ، الْيَهُودِيُّ مِنْ بَنِي زُرَيْقٍ‏.‏ قَالَ فِيمَا ذَا قَالَ فِي مُشْطٍ وَمُشَاطَةٍ، وَجُفِّ طَلْعَةٍ ذَكَرٍ‏.‏ قَالَ فَأَيْنَ هُوَ قَالَ فِي بِئْرِ ذِي أَرْوَانَ ‏"‏‏.‏ قَالَ فَذَهَبَ النَّبِيُّ صلى الله عليه وسلم فِي أُنَاسٍ مِنْ أَصْحَابِهِ إِلَى الْبِئْرِ، فَنَظَرَ إِلَيْهَا وَعَلَيْهَا نَخْلٌ، ثُمَّ رَجَعَ إِلَى عَائِشَةَ فَقَالَ ‏"‏ وَاللَّهِ لَكَأَنَّ مَاءَهَا نُقَاعَةُ الْحِنَّاءِ، وَلَكَأَنَّ نَخْلَهَا رُءُوسُ الشَّيَاطِينِ ‏"‏‏.‏ قُلْتُ يَا رَسُولَ اللَّهِ أَفَأَخْرَجْتَهُ قَالَ ‏"‏ لاَ، أَمَّا أَنَا فَقَدْ عَافَانِي اللَّهُ وَشَفَانِي، وَخَشِيتُ أَنْ أُثَوِّرَ عَلَى النَّاسِ مِنْهُ شَرًّا ‏"‏‏.‏ وَأَمَرَ بِهَا فَدُفِنَتْ‏.‏\hadithno{5766}\hadithtrans{Narrated `Aisha:Magic was worked on Allah's Messenger (ﷺ) so that he began to imagine that he had done something although he had not. One day while he was with me, he invoked Allah and invoked for a long period and then said, "O `Aisha! Do you know that Allah has instructed me regarding the matter I asked Him about?" I asked, "What is that, O Allah's Messenger (ﷺ)?" He said, "Two men came to me; one of them sat near my head and the other sat near my feet. One of them asked his companion, 'What is the disease of this man?' The other replied, 'He is under the effect of magic.' The first one asked, 'Who has worked magic on him?" The other replied, 'Labid bin A'sam, a Jew from the tribe of Bani Zuraiq.' The (first one asked), 'With what has it been done?' The other replied, 'With a a comb and the hair stuck to it and a skin of the pollen of a male datepalm tree.' The first one asked, 'Where is it?' The other replied, 'In the well of Dharwan.' Then the Prophet (ﷺ) went along with some of his companions to that well and looked at that and there were date palms near to it. Then he returned to me and said, 'By Allah the water of that well was (red) like the infusion of Henna leaves and its date-palms were like the heads of devils" I said, O Allah's Messenger (ﷺ)! Did you take those materials out of the pollen skin?" He said, 'No! As for me Allah has healed me and cured me and I was afraid that (by Showing that to the people) I would spread evil among them when he ordered that the well be filled up with earth, and it was filled up with earth}}
\hadithdefcmd{bukhari}{5767}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ ـ رضى الله عنهما أَنَّهُ قَدِمَ رَجُلاَنِ مِنَ الْمَشْرِقِ، فَخَطَبَا، فَعَجِبَ النَّاسُ لِبَيَانِهِمَا، فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ مِنَ الْبَيَانِ لَسِحْرًا ـ أَوْ ـ إِنَّ بَعْضَ الْبَيَانِ لَسِحْرٌ ‏"‏‏.‏\hadithno{5767}\hadithtrans{Narrated `Abdullah bin `Umar:Two men came from the East and addressed the people who wondered at their eloquent speeches On that Allah's Messenger (ﷺ) said. Some eloquent speech is as effective as magic}}
\hadithdefcmd{bukhari}{5768}{حَدَّثَنَا عَلِيٌّ، حَدَّثَنَا مَرْوَانُ، أَخْبَرَنَا هَاشِمٌ، أَخْبَرَنَا عَامِرُ بْنُ سَعْدٍ، عَنْ أَبِيهِ ـ رضى الله عنه ـ قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ مَنِ اصْطَبَحَ كُلَّ يَوْمٍ تَمَرَاتٍ عَجْوَةً، لَمْ يَضُرُّهُ سَمٌّ وَلاَ سِحْرٌ ذَلِكَ الْيَوْمَ إِلَى اللَّيْلِ ‏"‏‏.‏ وَقَالَ غَيْرُهُ ‏"‏ سَبْعَ تَمَرَاتٍ ‏"‏‏.‏\hadithno{5768}\hadithtrans{Narrated Saud:The Prophet (ﷺ) said, "If somebody takes some `Ajwa dates every morning, he will not be affected by poison or magic on that day till night." (Another narrator said seven dates)}}
\hadithdefcmd{bukhari}{5769}{حَدَّثَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، أَخْبَرَنَا أَبُو أُسَامَةَ، حَدَّثَنَا هَاشِمُ بْنُ هَاشِمٍ، قَالَ سَمِعْتُ عَامِرَ بْنَ سَعْدٍ، سَمِعْتُ سَعْدًا ـ رضى الله عنه ـ يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَنْ تَصَبَّحَ سَبْعَ تَمَرَاتٍ عَجْوَةً، لَمْ يَضُرُّهُ ذَلِكَ الْيَوْمَ سَمٌّ وَلاَ سِحْرٌ ‏"‏‏.‏\hadithno{5769}\hadithtrans{Narrated Saud:I heard Allah's Messenger (ﷺ) saying, "If Somebody takes seven 'Ajwa dates in the morning, neither magic nor poison will hurt him that day}}
\hadithdefcmd{bukhari}{5770}{حَدَّثَنِي عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، حَدَّثَنَا هِشَامُ بْنُ يُوسُفَ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ لاَ عَدْوَى، وَلاَ صَفَرَ، وَلاَ هَامَةَ ‏"‏‏.‏ فَقَالَ أَعْرَابِيٌّ يَا رَسُولَ اللَّهِ فَمَا بَالُ الإِبِلِ تَكُونُ فِي الرَّمْلِ كَأَنَّهَا الظِّبَاءُ، فَيُخَالِطُهَا الْبَعِيرُ الأَجْرَبُ فَيُجْرِبُهَا‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ فَمَنْ أَعْدَى الأَوَّلَ ‏"‏‏.‏\hadithno{5770}\hadithtrans{Narrated Abu Huraira: The Prophet (ﷺ) said, 'No 'Adwa (i.e. no contagious disease is conveyed to others without Allah's permission); nor (any evil omen in the month of) Safar; nor Hama" A bedouin said, "O Allah's Messenger (ﷺ)! What about the camels which, when on the sand (desert) look like deers, but when a mangy camel mixes with them they all get infected with mange?" On that Allah's Apostle said, "Then who conveyed the (mange) disease to the first (mangy) camel?}}
\hadithdefcmd{bukhari}{5771}{وَعَنْ أَبِي سَلَمَةَ، سَمِعَ أَبَا هُرَيْرَةَ، بَعْدُ يَقُولُ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ لاَ يُورِدَنَّ مُمْرِضٌ عَلَى مُصِحٍّ ‏"‏‏.‏ وَأَنْكَرَ أَبُو هُرَيْرَةَ حَدِيثَ الأَوَّلِ قُلْنَا أَلَمْ تُحَدِّثْ أَنَّهُ لاَ عَدْوَى فَرَطَنَ بِالْحَبَشِيَّةِ‏.‏ قَالَ أَبُو سَلَمَةَ فَمَا رَأَيْتُهُ نَسِيَ حَدِيثًا غَيْرَهُ‏.‏\hadithno{5771}\hadithtrans{Narrated Abu Huraira: Allah's Messenger (ﷺ) said: The cattle (sheep, cows, camels, etc.) suffering from a disease should not be mixed up with healthy cattle, (or said: "Do not put a patient with a healthy person ). " (as a precaution)}}
\hadithdefcmd{bukhari}{5772}{حَدَّثَنَا سَعِيدُ بْنُ عُفَيْرٍ، قَالَ حَدَّثَنِي ابْنُ وَهْبٍ، عَنْ يُونُسَ، عَنِ ابْنِ شِهَابٍ، قَالَ أَخْبَرَنِي سَالِمُ بْنُ عَبْدِ اللَّهِ، وَحَمْزَةُ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ ـ رضى الله عنهما ـ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ عَدْوَى، وَلاَ طِيَرَةَ، إِنَّمَا الشُّؤْمُ فِي ثَلاَثٍ فِي الْفَرَسِ، وَالْمَرْأَةِ، وَالدَّارِ ‏"‏‏.‏\hadithno{5772}\hadithtrans{Narrated `Abdullah bin `Umar:Allah's Messenger (ﷺ) said, "there is neither 'Adwa nor Tiyara, and an evil omen is only in three: a horse, a woman and a house}}
\hadithdefcmd{bukhari}{5775}{\hadithno{5775}\hadithtrans{}}
\hadithdefcmd{bukhari}{5776}{حَدَّثَنِي مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا ابْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، قَالَ سَمِعْتُ قَتَادَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ لاَ عَدْوَى، وَلاَ طِيَرَةَ، وَيُعْجِبُنِي الْفَأْلُ ‏"‏‏.‏ قَالُوا وَمَا الْفَأْلُ قَالَ ‏"‏ كَلِمَةٌ طَيِّبَةٌ ‏"‏‏.‏\hadithno{5776}\hadithtrans{Narrated Anas bin Malik:The Prophet (ﷺ) said, "No 'Adwa nor Tiyara; but I like Fal." They said, "What is the Fal?" He said, "A good word}}
\hadithdefcmd{bukhari}{5777}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا اللَّيْثُ، عَنْ سَعِيدِ بْنِ أَبِي سَعِيدٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّهُ قَالَ لَمَّا فُتِحَتْ خَيْبَرُ أُهْدِيَتْ لِرَسُولِ اللَّهِ صلى الله عليه وسلم شَاةٌ فِيهَا سَمٌّ، فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ اجْمَعُوا لِي مَنْ كَانَ هَا هُنَا مِنَ الْيَهُودِ ‏"‏‏.‏ فَجُمِعُوا لَهُ فَقَالَ لَهُمْ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنِّي سَائِلُكُمْ عَنْ شَىْءٍ فَهَلْ أَنْتُمْ صَادِقِيَّ عَنْهُ ‏"‏‏.‏ فَقَالُوا نَعَمْ يَا أَبَا الْقَاسِمِ‏.‏ فَقَالَ لَهُمْ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَنْ أَبُوكُمْ ‏"‏‏.‏ قَالُوا أَبُونَا فُلاَنٌ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ كَذَبْتُمْ بَلْ أَبُوكُمْ فُلاَنٌ ‏"‏‏.‏ فَقَالُوا صَدَقْتَ وَبَرِرْتَ‏.‏ فَقَالَ ‏"‏ هَلْ أَنْتُمْ صَادِقِيَّ عَنْ شَىْءٍ إِنْ سَأَلْتُكُمْ عَنْهُ ‏"‏‏.‏ فَقَالُوا نَعَمْ يَا أَبَا الْقَاسِمِ، وَإِنْ كَذَبْنَاكَ عَرَفْتَ كَذِبَنَا كَمَا عَرَفْتَهُ فِي أَبِينَا‏.‏ قَالَ لَهُمْ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَنْ أَهْلُ النَّارِ ‏"‏‏.‏ فَقَالُوا نَكُونُ فِيهَا يَسِيرًا، ثُمَّ تَخْلُفُونَنَا فِيهَا‏.‏ فَقَالَ لَهُمْ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ اخْسَئُوا فِيهَا، وَاللَّهِ لاَ نَخْلُفُكُمْ فِيهَا أَبَدًا ‏"‏‏.‏ ثُمَّ قَالَ لَهُمْ ‏"‏ فَهَلْ أَنْتُمْ صَادِقِيَّ عَنْ شَىْءٍ إِنْ سَأَلْتُكُمْ عَنْهُ ‏"‏‏.‏ قَالُوا نَعَمْ‏.‏ فَقَالَ ‏"‏ هَلْ جَعَلْتُمْ فِي هَذِهِ الشَّاةِ سُمًّا ‏"‏‏.‏ فَقَالُوا نَعَمْ‏.‏ فَقَالَ ‏"‏ مَا حَمَلَكُمْ عَلَى ذَلِكَ ‏"‏‏.‏ فَقَالُوا أَرَدْنَا إِنْ كُنْتَ كَذَّابًا نَسْتَرِيحُ مِنْكَ، وَإِنْ كُنْتَ نَبِيًّا لَمْ يَضُرَّكَ‏.‏\hadithno{5777}\hadithtrans{Narrated Abu Huraira:When Khaibar was conquered, Allah's Messenger (ﷺ) was presented with a poisoned (roasted) sheep. Allah's Apostle said, "Collect for me all the Jews present in this area." (When they were gathered) Allah's Apostle said to them, "I am going to ask you about something; will you tell me the truth?" They replied, "Yes, O Abal-Qasim!" Allah's Messenger (ﷺ) said to them, "Who is your father?" They said, "Our father is so-and-so." Allah's Messenger (ﷺ) said, "You have told a lie. for your father is so-and-so," They said, "No doubt, you have said the truth and done the correct thing." He again said to them, "If I ask you about something; will you tell me the truth?" They replied, "Yes, O Abal-Qasim! And if we should tell a lie you will know it as you have known it regarding our father," Allah's Messenger (ﷺ) then asked, "Who are the people of the (Hell) Fire?" They replied, "We will remain in the (Hell) Fire for a while and then you (Muslims) will replace us in it" Allah's Messenger (ﷺ) said to them. ''You will abide in it with ignominy. By Allah, we shall never replace you in it at all." Then he asked them again, "If I ask you something, will you tell me the truth?" They replied, "Yes." He asked. "Have you put the poison in this roasted sheep?" They replied, "Yes," He asked, "What made you do that?" They replied, "We intended to learn if you were a liar in which case we would be relieved from you, and if you were a prophet then it would not harm you}}
\hadithdefcmd{bukhari}{5778}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَبْدِ الْوَهَّابِ، حَدَّثَنَا خَالِدُ بْنُ الْحَارِثِ، حَدَّثَنَا شُعْبَةُ، عَنْ سُلَيْمَانَ، قَالَ سَمِعْتُ ذَكْوَانَ، يُحَدِّثُ عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ تَرَدَّى مِنْ جَبَلٍ فَقَتَلَ نَفْسَهُ، فَهْوَ فِي نَارِ جَهَنَّمَ، يَتَرَدَّى فِيهِ خَالِدًا مُخَلَّدًا فِيهَا أَبَدًا، وَمَنْ تَحَسَّى سَمًّا فَقَتَلَ نَفْسَهُ، فَسَمُّهُ فِي يَدِهِ، يَتَحَسَّاهُ فِي نَارِ جَهَنَّمَ خَالِدًا مُخَلَّدًا فِيهَا أَبَدًا، وَمَنْ قَتَلَ نَفْسَهُ بِحَدِيدَةٍ، فَحَدِيدَتُهُ فِي يَدِهِ، يَجَأُ بِهَا فِي بَطْنِهِ فِي نَارِ جَهَنَّمَ خَالِدًا مُخَلَّدًا فِيهَا أَبَدًا ‏"‏‏.‏\hadithno{5778}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "Whoever purposely throws himself from a mountain and kills himself, will be in the (Hell) Fire falling down into it and abiding therein perpetually forever; and whoever drinks poison and kills himself with it, he will be carrying his poison in his hand and drinking it in the (Hell) Fire wherein he will abide eternally forever; and whoever kills himself with an iron weapon, will be carrying that weapon in his hand and stabbing his `Abdomen with it in the (Hell) Fire wherein he will abide eternally forever}}
\hadithdefcmd{bukhari}{5779}{حَدَّثَنَا مُحَمَّدٌ، أَخْبَرَنَا أَحْمَدُ بْنُ بَشِيرٍ أَبُو بَكْرٍ، أَخْبَرَنَا هَاشِمُ بْنُ هَاشِمٍ، قَالَ أَخْبَرَنِي عَامِرُ بْنُ سَعْدٍ، قَالَ سَمِعْتُ أَبِي يَقُولُ، سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَنِ اصْطَبَحَ بِسَبْعِ تَمَرَاتٍ عَجْوَةٍ لَمْ يَضُرَّهُ ذَلِكَ الْيَوْمَ سَمٌّ وَلاَ سِحْرٌ ‏"‏‏.‏\hadithno{5779}\hadithtrans{Narrated Sa`d:I heard Allah's Messenger (ﷺ) saying, "Whoever takes seven 'Ajwa dates in the morning will not be effected by magic or poison on that day}}
\hadithdefcmd{bukhari}{5781}{حَدَّثَنِي عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي إِدْرِيسَ الْخَوْلاَنِيِّ، عَنْ أَبِي ثَعْلَبَةَ الْخُشَنِيِّ، رضى الله عنه قَالَ نَهَى النَّبِيُّ صلى الله عليه وسلم عَنْ أَكْلِ كُلِّ ذِي نَابٍ مِنَ السَّبُعِ‏.‏ قَالَ الزُّهْرِيُّ وَلَمْ أَسْمَعْهُ حَتَّى أَتَيْتُ الشَّأْمَ‏.‏ وَزَادَ اللَّيْثُ قَالَ حَدَّثَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، قَالَ وَسَأَلْتُهُ هَلْ نَتَوَضَّأُ أَوْ نَشْرَبُ أَلْبَانَ الأُتُنِ أَوْ مَرَارَةَ السَّبُعِ أَوْ أَبْوَالَ الإِبِلِ‏.‏ قَالَ قَدْ كَانَ الْمُسْلِمُونَ يَتَدَاوَوْنَ بِهَا، فَلاَ يَرَوْنَ بِذَلِكَ بَأْسًا، فَأَمَّا أَلْبَانُ الأُتُنِ فَقَدْ بَلَغَنَا أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنْ لُحُومِهَا، وَلَمْ يَبْلُغْنَا عَنْ أَلْبَانِهَا أَمْرٌ وَلاَ نَهْىٌ، وَأَمَّا مَرَارَةُ السَّبُعِ قَالَ ابْنُ شِهَابٍ أَخْبَرَنِي أَبُو إِدْرِيسَ الْخَوْلاَنِيُّ أَنَّ أَبَا ثَعْلَبَةَ الْخُشَنِيَّ أَخْبَرَهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنْ أَكْلِ كُلِّ ذِي نَابٍ مِنَ السَّبُعِ‏.‏\hadithno{5781}\hadithtrans{Narrated Abu Tha`laba Al-Khushani:The Prophet (ﷺ) forbade the eating of wild animals having fangs. (Az-Zuhri said: I did not hear this narration except when I went to Sham.) Al-Laith said: Narrated Yunus: I asked Ibn Shihab, "May we perform the ablution with the milk of she-asses or drink it, or drink the bile of wild animals or urine of camels?" He replied, "The Muslims used to treat themselves with that and did not see any harm in it. As for the milk of she-asses, we have learnt that Allah's Messenger (ﷺ) forbade the eating of their meat, but we have not received any information whether drinking of their milk is allowed or forbidden." As for the bile of wild animals, Ibn Shihab said, "Abu Idris Al-Khaulani told me that Allah's Messenger (ﷺ) forbade the eating of the flesh of every wild beast having fangs}}
\hadithdefcmd{bukhari}{5782}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ جَعْفَرٍ، عَنْ عُتْبَةَ بْنِ مُسْلِمٍ، مَوْلَى بَنِي تَيْمٍ عَنْ عُبَيْدِ بْنِ حُنَيْنٍ، مَوْلَى بَنِي زُرَيْقٍ عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا وَقَعَ الذُّبَابُ فِي إِنَاءِ أَحَدِكُمْ، فَلْيَغْمِسْهُ كُلَّهُ، ثُمَّ لْيَطْرَحْهُ، فَإِنَّ فِي أَحَدِ جَنَاحَيْهِ شِفَاءً وَفِي الآخَرِ دَاءً ‏"‏‏.‏\hadithno{5782}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "If a fly falls in the vessel of any of you, let him dip all of it (into the vessel) and then throw it away, for in one of its wings there is a disease and in the other there is healing (antidote for it) i e. the treatment for that disease}}
